@@ -1,6 +1,6 @@
 /*
     terminatorX - realtime audio scratching software
-    Copyright (C) 1999-2014  Alexander König
+    Copyright (C) 1999-2016  Alexander König
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -85,7 +85,7 @@ void show_help()
 {
 			
 	fprintf(stderr, "\
-usage: terminatorX [options]n\
+usage: terminatorX [options]\n\
 \n\
   -h, --help 			Display help info\n\
   -f, --file			Load saved terminatorX set file\n\
@@ -175,30 +175,43 @@ void checkenv(const char *name)
 
 int main(int argc, char **argv)
 {
-	fprintf(stderr, "%s - Copyright (C) 1999-2014 by Alexander König\n", VERSIONSTRING);
-	fprintf(stderr, "terminatorX comes with ABSOLUTELY NO WARRANTY - for details read the license.\n");
+	bool keep_caps_failed = false;
+	bool root_dropped = false;
 
 #ifdef USE_CAPABILITIES	
 	if (!geteuid()) {
 		if (prctl(PR_SET_KEEPCAPS, 1, -1, -1, -1)) {
-			tX_error("failed to keep capabilites.");
+			keep_caps_failed = true;
 		}
 		set_nice_capability(CAP_PERMITTED);
 	}
 #endif
 
+	GError *mouse_error = mouse.open_channel();
+
 	if ((!geteuid()) && (getuid() != geteuid())) {
-		tX_msg("runnig suid-root - dropping root privileges.");
-		
 		int result=setuid(getuid());
+		root_dropped = true;
 		
 		if (result) {
-			tX_error("main() Panic: can't drop root privileges.");
+			tX_error("main() panic: can't drop root privileges.");
 			exit(2);
 		}
 	}
 	
 	/* No suidroot below this comment. */
+
+	fprintf(stderr, "%s - Copyright (C) 1999-2016 by Alexander König\n", VERSIONSTRING);
+	fprintf(stderr, "terminatorX comes with ABSOLUTELY NO WARRANTY - for details read the license.\n");
+
+	if (keep_caps_failed) {
+		tX_error("failed to keep capabilities.");
+	}
+
+	if (root_dropped) {
+		tX_msg("started suid-root - root privileges dropped.");
+	}
+
 	
 #ifdef USE_CAPABILITIES		
 	set_nice_capability(CAP_EFFECTIVE);	
@@ -237,12 +250,11 @@ int main(int argc, char **argv)
 #ifdef USE_SCHEDULER
 	tX_debug("main() GUI thread is p:%i, t:%i and has policy %i.", getpid(), (int) pthread_self(), sched_getscheduler(getpid()));
 #endif	
-	tx_icons_init();
 	create_mastergui(globals.width, globals.height);
 	
 	if (globals.show_nag) {
 		while (!timesup) {
-			while (gtk_events_pending()) gtk_main_iteration(); 
+			while (gtk_events_pending()) { gtk_main_iteration(); }
 			gdk_flush();				
 			usleep(250);
 		}
@@ -253,9 +265,10 @@ int main(int argc, char **argv)
 	jack_check();
 #endif
 	display_mastergui();
-		
+	
 	if (globals.startup_set) {
-		while (gtk_events_pending()) gtk_main_iteration(); gdk_flush();	
+		while (gtk_events_pending()) { gtk_main_iteration(); }
+		gdk_flush();	
 		tX_cursor::set_cursor(tX_cursor::WAIT_CURSOR);
 		load_tt_part(globals.startup_set);
 		tX_cursor::reset_cursor();
@@ -265,6 +278,39 @@ int main(int argc, char **argv)
 #endif		
 	}
 
+	if (mouse_error) {
+		char buffer[4096];
+		const char *errorFmt = "<span size=\"larger\" weight=\"bold\">Failed to access input hardware</span>\n\n"
+			"terminatorX failed to get direct access to the Linux input interface and "
+			"will now fall back to the standard \"pointer warp\" mode, which may result in "
+			"<span weight=\"bold\">significantly reduced scratching precision</span>.\n\nTo achieve "
+			"high precision scratching either\n - <span style=\"italic\">install terminatorX suid-root</span>, or\n"
+			" - <span style=\"italic\">add the users running terminatorX to a group that can access the special "
+			"file \"/dev/input/mice\"</span>\nand restart terminatorX.\n\n"
+			"The reported error was: <span weight=\"bold\">%s</span>";
+
+
+		if (globals.input_fallback_warning) {
+			snprintf(buffer, 4096, errorFmt, mouse_error->message);
+			GtkWidget *dialog=gtk_message_dialog_new_with_markup(GTK_WINDOW(main_window), GTK_DIALOG_DESTROY_WITH_PARENT,
+					GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE, "%s", "");
+			gtk_message_dialog_set_markup(GTK_MESSAGE_DIALOG(dialog), buffer);
+			GtkWidget *message_area = gtk_message_dialog_get_message_area(GTK_MESSAGE_DIALOG(dialog));
+			GtkWidget *check_button = gtk_check_button_new_with_mnemonic ("Show this warning next time");
+			gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check_button), 1);
+			gtk_widget_show(check_button);
+			gtk_box_pack_start(GTK_BOX(message_area), check_button, FALSE, FALSE, 0);
+			gtk_widget_grab_focus(gtk_dialog_get_widget_for_response(GTK_DIALOG(dialog), GTK_RESPONSE_CLOSE));
+			gtk_dialog_run(GTK_DIALOG(dialog));
+			globals.input_fallback_warning=gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(check_button));
+			gtk_widget_destroy(dialog);
+		} else {
+			tX_warning("Failed t access input hardware: %s", mouse_error->message);
+		}
+
+		g_error_free(mouse_error);
+	}
+		
 #ifdef USE_STARTUP_NOTIFICATION
 	gdk_notify_startup_complete();
 #endif	
@@ -274,6 +320,8 @@ int main(int argc, char **argv)
 
 	store_globals();
 
+	mouse.close_channel();
+
 	delete engine;
 	
 	fprintf(stderr, "Have a nice life.\n");
