@@ -1,6 +1,6 @@
 /*
     terminatorX - realtime audio scratching software
-    Copyright (C) 1999-2014  Alexander König
+    Copyright (C) 1999-2016  Alexander König
  
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -272,7 +272,7 @@ int tX_audiodevice_alsa :: open()
 	long unsigned int buffer_size;
 
 	if (snd_pcm_hw_params_get_buffer_size(hw_params, &buffer_size) < 0) {
-		tX_error("ALSA: failed to retreive buffer size");
+		tX_error("ALSA: failed to retrieve buffer size");
 		return -1;
 	}
 	
@@ -284,7 +284,7 @@ int tX_audiodevice_alsa :: open()
 	}
 	
 	if (snd_pcm_hw_params_get_period_size(hw_params, &period_size, &dir)<0) {
-		tX_error("ALSA: failed to retreive period size");
+		tX_error("ALSA: failed to retrieve period size");
 		return -1;
 	}
 	
@@ -351,10 +351,246 @@ void tX_audiodevice_alsa :: play(int16_t *buffer)
 
 #endif //USE_ALSA
 
+#ifdef USE_PULSE
+#include <pulse/error.h>
+
+void tX_audiodevice_pulse::wrap_stream_started_callback(pa_stream *stream, void *userdata) {
+	tX_audiodevice_pulse *device = (tX_audiodevice_pulse *) userdata;
+	device->stream_started_callback(stream);
+}
+
+void tX_audiodevice_pulse::wrap_stream_underflow_callback(pa_stream *stream, void *userdata) {
+	tX_audiodevice_pulse *device = (tX_audiodevice_pulse *) userdata;
+	device->stream_underflow_callback(stream);
+}
+
+void tX_audiodevice_pulse::wrap_stream_overflow_callback(pa_stream *stream, void *userdata) {
+	tX_audiodevice_pulse *device = (tX_audiodevice_pulse *) userdata;
+	device->stream_overflow_callback(stream);
+}
+
+void tX_audiodevice_pulse::wrap_stream_drain_complete_callback(pa_stream *stream, int success, void *userdata) {
+	tX_audiodevice_pulse *device = (tX_audiodevice_pulse *) userdata;
+	device->stream_drain_complete_callback(stream, success);
+}
+
+void tX_audiodevice_pulse::wrap_stream_trigger_success_callback(pa_stream *stream, int success, void *userdata) {
+	tX_audiodevice_pulse *device = (tX_audiodevice_pulse *) userdata;
+	device->stream_trigger_success_callback(stream, success);
+}
+
+void tX_audiodevice_pulse::wrap_stream_write_callback(pa_stream *stream, size_t length, void *userdata) {
+	tX_audiodevice_pulse *device = (tX_audiodevice_pulse *) userdata;
+	device->stream_write_callback(stream, length);
+}
+
+void tX_audiodevice_pulse::wrap_context_state_callback(pa_context *context, void *userdata) {
+	tX_audiodevice_pulse *device = (tX_audiodevice_pulse *) userdata;
+	device->context_state_callback(context);
+}
+
+void tX_audiodevice_pulse::context_state_callback(pa_context *context) {
+	pa_context_state_t state;
+
+	state = pa_context_get_state(context);
+
+	tX_debug("pulseaudio context state: %i", state);
+	switch (state) {
+		case PA_CONTEXT_UNCONNECTED:
+		case PA_CONTEXT_CONNECTING:
+		case PA_CONTEXT_AUTHORIZING:
+		case PA_CONTEXT_SETTING_NAME:
+			break;
+		case PA_CONTEXT_FAILED:
+		case PA_CONTEXT_TERMINATED:
+			if (!engine->is_stopped()) {
+				tX_error("pulseaudio disconnected");
+			}
+			break;
+
+		case PA_CONTEXT_READY:
+			pa_sample_spec spec = {
+				.format = PA_SAMPLE_S16LE,
+				.rate = 44100,
+				.channels = 2
+		 	};
+	
+			pa_buffer_attr attr = {
+				.maxlength = (uint32_t) -1,
+				.tlength = (uint32_t) (globals.pulse_buffer_length * 2 * sizeof(int16_t)), // 2 bytes per sample, 2 channels
+				.prebuf = (uint32_t) -1,
+				.minreq = (uint32_t) -1,
+				.fragsize = (uint32_t) -1
+			};
+
+			pa_stream_flags_t flags = PA_STREAM_ADJUST_LATENCY;
+
+			if ((stream = pa_stream_new(context, "terminatorX", &spec, NULL))) {
+				tX_debug("pulseaudio stream created");
+				//pa_stream_set_started_callback(stream, tX_audiodevice_pulse::wrap_stream_started_callback, this);
+				//pa_stream_set_underflow_callback(stream, tX_audiodevice_pulse::wrap_stream_underflow_callback, this);
+				pa_stream_set_overflow_callback(stream, tX_audiodevice_pulse::wrap_stream_overflow_callback, this);
+				pa_stream_set_write_callback(stream, tX_audiodevice_pulse::wrap_stream_write_callback, this);
+
+				if (pa_stream_connect_playback(stream, NULL, &attr, flags, NULL, NULL) >= 0) {
+					// start the playback.
+					pa_stream_trigger(stream, tX_audiodevice_pulse::wrap_stream_trigger_success_callback, this);
+				} else {
+					tX_error("Failed to connect pulseaudio stream playback: %s", pa_strerror(pa_context_errno(context)));
+				}
+			}	else {
+				tX_error("Failed to create pulseaudio stream: %s", pa_strerror(pa_context_errno(context)));
+			}
+			break;
+	}
+}
+
+void tX_audiodevice_pulse::wrap_context_drain_complete_callback(pa_context *context, void *userdata) {
+	tX_audiodevice_pulse *device = (tX_audiodevice_pulse *) userdata;
+	device->context_drain_complete_callback(context);
+}
+
+void tX_audiodevice_pulse::context_drain_complete_callback(pa_context *context) {
+	pa_context_disconnect(context);
+	is_open = false;
+	pa_mainloop_quit(mainloop, 0);
+}
+
+void tX_audiodevice_pulse::stream_started_callback(pa_stream *stream) {
+	tX_debug("pulseaudio stream started");
+}
+
+void tX_audiodevice_pulse::stream_underflow_callback(pa_stream *stream) {
+	tX_debug("pulseaudio stream underflow");
+}
+
+void tX_audiodevice_pulse::stream_overflow_callback(pa_stream *stream) {
+	tX_debug("pulseaudio stream overflow");
+}
+
+void tX_audiodevice_pulse::stream_trigger_success_callback(pa_stream *stream, int success) {
+	tX_debug("pulseaudio trigger success %i", success);
+}
+
+void tX_audiodevice_pulse::stream_drain_complete_callback(pa_stream *stream, int success) {
+	if (!success) {
+		tX_debug("pulseaudio drain failed %s", pa_strerror(pa_context_errno(context)));
+	} else {
+		pa_operation *operation;
+		pa_stream_disconnect(stream);
+		pa_stream_unref(stream);
+		stream = NULL;
+
+		if (!(operation = pa_context_drain(context, tX_audiodevice_pulse::wrap_context_drain_complete_callback, this))) {
+			pa_context_disconnect(context);
+			is_open = false;
+			pa_mainloop_quit(mainloop, -1);
+		} else {
+			pa_operation_unref(operation);
+		}
+	}
+}
+
+void tX_audiodevice_pulse::stream_write_callback(pa_stream *stream, size_t length) {
+	size_t sample_length = length/2;
+
+	if (engine->is_stopped()) {
+		tX_debug("pulseaudio write callback trying to disconnect pulseaudio");
+		pa_operation *operation;
+		pa_stream_set_write_callback(stream, NULL, NULL);
+		if (!(operation = pa_stream_drain(stream, tX_audiodevice_pulse::wrap_stream_drain_complete_callback, this))) {
+			tX_error("pulseaudio failed to initiate drain %s", pa_strerror(pa_context_errno(context)));
+		}
+		pa_operation_unref(operation);
+	} else {
+		unsigned int outbuffer_pos=0;
+		unsigned int sample;
+	
+		int16_t *outbuffer = NULL;
+		size_t outbuffer_bytes = length;
+		pa_stream_begin_write(stream, (void **) &outbuffer, &outbuffer_bytes);
+
+		if (samples_in_overrun_buffer) {
+			memcpy(outbuffer, overrun_buffer, sizeof(int16_t) * samples_in_overrun_buffer);
+			outbuffer_pos+=samples_in_overrun_buffer;
+		}
+	
+		while (outbuffer_pos<sample_length) {
+			int16_t *data=engine->render_cycle();
+
+			sample = tX_min(vtt_class::samples_in_mix_buffer, (sample_length - outbuffer_pos));
+
+			memcpy(&outbuffer[outbuffer_pos], data, sizeof(int16_t) * sample);
+			outbuffer_pos+=sample;
+		
+			if (sample < vtt_class::samples_in_mix_buffer) {
+				samples_in_overrun_buffer=vtt_class::samples_in_mix_buffer-sample;
+				/* There's more data in the mixbuffer... */
+				memcpy(overrun_buffer, &data[sample], sizeof(int16_t) * samples_in_overrun_buffer);
+			} else {
+				samples_in_overrun_buffer=0;
+			}
+		}
+	
+		if (pa_stream_write(stream, (uint8_t *) outbuffer, length, NULL, 0, PA_SEEK_RELATIVE) < 0) {
+			tX_error("pulseaudio error writing to stream: %s", pa_strerror(pa_context_errno(context)));
+		}
+		outbuffer = NULL;
+	}
+}
+
+void tX_audiodevice_pulse::start() {
+	overrun_buffer=new int16_t[vtt_class::samples_in_mix_buffer];
+	samples_in_overrun_buffer = 0;
+	int result;
+	
+	tX_debug("handover flow control to pulseaudio");
+
+	while (!engine->is_stopped()) {
+		pa_mainloop_run(mainloop, &result);
+		tX_debug("pulseaudio mainloop has terminated: %i", result);
+	}	
+	
+	delete [] overrun_buffer;
+}
+
+int tX_audiodevice_pulse::open() {
+	mainloop = pa_mainloop_new();
+	mainloop_api = pa_mainloop_get_api(mainloop);
+	context = pa_context_new(mainloop_api, "terminatorX");
+	pa_context_flags_t flags = PA_CONTEXT_NOFLAGS;
+	pa_context_connect(context, NULL, flags, NULL);
+	pa_context_set_state_callback(context, tX_audiodevice_pulse::wrap_context_state_callback, this);
+
+	sample_rate=44100;
+	tX_debug("pulseaudio opened.");
+
+	is_open = true;
+	return 0;
+}
+
+int tX_audiodevice_pulse :: close() {
+	return 0;
+}
+
+tX_audiodevice_pulse :: tX_audiodevice_pulse() : tX_audiodevice(),
+mainloop(NULL), mainloop_api(NULL), context(NULL), stream(NULL)  {
+}
+
+void tX_audiodevice_pulse :: play(int16_t *buffer) {
+	tX_error("tX_audiodevice_pulse::play()");
+}
+
+tX_audiodevice_pulse :: ~tX_audiodevice_pulse() {
+}
+
+#endif //USE_PULSE
+
 #ifdef USE_JACK
 
 tX_jack_client tX_jack_client::instance;
 
+
 bool tX_jack_client::init()
 {
 	if (!client_initialized) {
