@@ -1,6 +1,6 @@
 /*
     terminatorX - realtime audio scratching software
-    Copyright (C) 1999-2014  Alexander König
+    Copyright (C) 1999-2016  Alexander König
  
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -40,6 +40,10 @@
 #include <jack/jack.h>
 #endif
 
+#ifdef USE_PULSE
+#include <pulse/pulseaudio.h>
+#endif
+
 class tX_engine;
 
 class tX_audiodevice
@@ -107,6 +111,56 @@ class tX_audiodevice_alsa : public tX_audiodevice
 
 #endif
 
+#ifdef USE_PULSE
+
+class tX_audiodevice_pulse : public tX_audiodevice
+{
+	pa_mainloop *mainloop;
+	pa_mainloop_api *mainloop_api;
+	pa_context *context;
+	pa_stream *stream;
+	int16_t *overrun_buffer;
+	unsigned int samples_in_overrun_buffer;
+
+	public:
+	virtual int open();
+	virtual int close();
+	virtual void start();
+	virtual void play(int16_t*);
+
+	tX_audiodevice_pulse();
+	~tX_audiodevice_pulse();
+	
+	private:
+	// context callbacks
+	static void wrap_context_state_callback(pa_context *context, void *userdata);
+	void context_state_callback(pa_context *context);
+
+	static void wrap_context_drain_complete_callback(pa_context *context, void *userdata);
+	void context_drain_complete_callback(pa_context *context);
+
+	// stream callbacks
+	static void wrap_stream_started_callback(pa_stream *stream, void *userdata);
+	void stream_started_callback(pa_stream *stream);
+
+	static void wrap_stream_underflow_callback(pa_stream *stream, void *userdata);
+	void stream_underflow_callback(pa_stream *stream);
+	
+	static void wrap_stream_overflow_callback(pa_stream *stream, void *userdata);
+	void stream_overflow_callback(pa_stream *stream);
+	
+	static void wrap_stream_drain_complete_callback(pa_stream *stream, int success, void *userdata);
+	void stream_drain_complete_callback(pa_stream *stream, int success);
+
+	static void wrap_stream_trigger_success_callback(pa_stream *stream, int success, void *userdata);
+	void stream_trigger_success_callback(pa_stream *stream, int success);
+
+	static void wrap_stream_write_callback(pa_stream *stream, size_t length, void *userdata);
+	void stream_write_callback(pa_stream *stream, size_t length);
+};
+
+#endif
+
 #ifdef USE_JACK
 
 class tX_jack_client;
