@@ -1,6 +1,6 @@
 /*
     terminatorX - realtime audio scratching software
-    Copyright (C) 1999-2014  Alexander König
+    Copyright (C) 1999-2016  Alexander König
  
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -29,18 +29,12 @@
 #include <gtk/gtk.h>
 #include <string.h>
 #include <gdk/gdk.h>
-#include "tX_icon.h"
 #include "tX_ui_interface.h"
 #include "tX_ui_support.h"
 
 #include "tX_widget.h"
 #include "tX_flash.h"
 
-#ifndef WIN32
-#include <X11/extensions/XInput.h>
-#include <X11/X.h>
-#endif
-
 #include "license.c"
 #include "tX_mastergui.h"
 #include "version.h"
@@ -48,6 +42,8 @@
 #include <dirent.h>
 #include "tX_engine.h"
 
+#include "icons/tX_dialog_resources.c"
+
 #ifdef USE_SCHEDULER
 #include <sched.h>
 #include <pthread.h>
@@ -71,6 +67,8 @@ void apply_options(GtkWidget *dialog) {
 		globals.audiodevice_type=OSS;
 	} else if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(lookup_widget(dialog, "jack_driver")))) {
 		globals.audiodevice_type=JACK;
+	} else if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(lookup_widget(dialog, "pulse_driver")))) {
+		globals.audiodevice_type=PULSE;
 	}
 	globals.use_realtime=gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(lookup_widget(dialog, "use_realtime")));
 	
@@ -94,16 +92,11 @@ void apply_options(GtkWidget *dialog) {
 	globals.alsa_period_time*=1000;
 	globals.alsa_samplerate=atoi(gtk_combo_box_text_get_active_text(GTK_COMBO_BOX_TEXT(lookup_widget(dialog, "alsa_samplerate"))));	
 	globals.alsa_free_hwstats=gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(lookup_widget(dialog, "alsa_free_hwstats")));
-	
+	globals.pulse_buffer_length=(int) gtk_range_get_value(GTK_RANGE(lookup_widget(dialog, "pulse_buffer_size")));
+
 	/* TODO: JACK
 	*/
 	
-	/* Input */
-	globals.xinput_enable=(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(lookup_widget(dialog, "xinput_enable")))==TRUE);
-	char *xinput_device = gtk_combo_box_text_get_active_text(GTK_COMBO_BOX_TEXT(lookup_widget(dialog, "xinput_device")));
-	if (xinput_device) {
-		strcpy(globals.xinput_device, xinput_device);
-	}
 	globals.mouse_speed=gtk_range_get_value(GTK_RANGE(lookup_widget(dialog, "mouse_speed")));
 	globals.sense_cycles=(int) gtk_range_get_value(GTK_RANGE(lookup_widget(dialog, "stop_sense_cycles")));
 	globals.vtt_inertia=gtk_range_get_value(GTK_RANGE(lookup_widget(dialog, "vtt_inertia")));
@@ -127,7 +120,15 @@ void apply_options(GtkWidget *dialog) {
 	globals.update_delay=(int) gtk_range_get_value(GTK_RANGE(lookup_widget(dialog, "update_delay")));
 	globals.update_idle=(int) gtk_range_get_value(GTK_RANGE(lookup_widget(dialog, "update_idle")));
 	globals.flash_response=gtk_range_get_value(GTK_RANGE(lookup_widget(dialog, "vumeter_decay")));
-	
+
+	if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(lookup_widget(dialog, "override_knob_size")))) {
+		globals.knob_size_override=gtk_range_get_value(GTK_RANGE(lookup_widget(dialog, "knob_size")));
+	} else {
+		globals.knob_size_override = 0;
+	}
+
+	globals.wav_display_history=(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(lookup_widget(dialog, "wav_display_history")))==TRUE);
+
 	/* Audio Colors */
 	
 	strcpy(globals.wav_display_bg_focus, (char *) g_object_get_data(G_OBJECT(lookup_widget(dialog, "wav_display_bg_focus")), "Color"));
@@ -177,11 +178,11 @@ void apply_options(GtkWidget *dialog) {
 #define WID_FIX FALSE, FALSE, 0
 
 #define my_new_subsec(s); \
-	separator=gtk_hseparator_new(); \
+	separator=gtk_separator_new(GTK_ORIENTATION_HORIZONTAL); \
 	gtk_box_pack_start(GTK_BOX(vbox), separator, WID_DYN);\
 	gtk_widget_show(separator); \
 	label=gtk_label_new(s); \
-	gtk_misc_set_alignment (GTK_MISC(label), 0 ,0.5); \
+	gtk_widget_set_halign(label, GTK_ALIGN_START); \
 	gtk_box_pack_start(GTK_BOX(vbox), label, WID_DYN); \
 	gtk_widget_show(label); 
 
@@ -191,7 +192,7 @@ void apply_options(GtkWidget *dialog) {
 	gtk_widget_show(btn);
 	
 
-#define begin_box(); box=gtk_hbox_new(FALSE, 5);
+#define begin_box(); box=gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 5);
 
 #define begin_hom_box(); box=gtk_hbox_new(TRUE, 5);
 
@@ -205,11 +206,9 @@ void apply_options(GtkWidget *dialog) {
 	gtk_widget_show(wid);
 
 #define add_expl(s); label=gtk_label_new(s); \
-	gtk_misc_set_alignment(GTK_MISC(label), 0.5, 0.5);\
 	add_widget_fix(label);
 
 #define add_expl_dyn(s); label=gtk_label_new(s); \
-	gtk_misc_set_alignment(GTK_MISC(label), 0.5, 0.5);\
 	add_widget_dyn(label);
 
 #ifdef USE_ALSA
@@ -297,22 +296,6 @@ void append_sampling_rates_list(GtkComboBoxText *combo, int current) {
 	}
 }
 
-void append_xinput_devices_list(GtkComboBoxText *combo, char *current) {
-	int devmax;
-	Display *dpy=XOpenDisplay(NULL);
-	XDeviceInfo *xdev=XListInputDevices(dpy, &devmax);
-	XCloseDisplay(dpy);
-
-	for (int i=0; i<devmax; i++) {		
-		gtk_combo_box_text_append_text(combo, strdup(xdev[i].name));
-		if (strcmp(xdev[i].name, current) == 0) {
-			gtk_combo_box_set_active(GTK_COMBO_BOX(combo), i);
-		}
-	}
-	
-	XFreeDeviceList(xdev);
-}
-
 #define MAX_COLORS 10
 char *colors[MAX_COLORS]={ NULL };
 
@@ -342,6 +325,9 @@ void init_tx_options(GtkWidget *dialog) {
 		case JACK: gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(lookup_widget(dialog, "jack_driver")), 1);
 			break;
 
+		case PULSE: gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(lookup_widget(dialog, "pulse_driver")), 1);
+			break;
+
 		case OSS: 
 		default:
 			gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(lookup_widget(dialog, "oss_driver")), 1);
@@ -365,12 +351,21 @@ void init_tx_options(GtkWidget *dialog) {
 	
 #ifndef USE_ALSA
 	gtk_widget_set_sensitive(lookup_widget(dialog, "alsa_driver"), 0);	
-	// TODO: Rest!	
+        gtk_widget_set_sensitive(lookup_widget(dialog, "alsa_audio_device"), 0);
+        gtk_widget_set_sensitive(lookup_widget(dialog, "alsa_samplerate"), 0);
+        gtk_widget_set_sensitive(lookup_widget(dialog, "alsa_period_time"), 0);
+        gtk_widget_set_sensitive(lookup_widget(dialog, "alsa_buffer_time"), 0);
+        gtk_widget_set_sensitive(lookup_widget(dialog, "alsa_free_hwstats"), 0);
 #endif
 	
 #ifndef USE_JACK
 	gtk_widget_set_sensitive(lookup_widget(dialog, "jack_driver"), 0);
 #endif	
+
+#ifndef USE_PULSE
+	gtk_widget_set_sensitive(lookup_widget(dialog, "pulse_driver"), 0);
+	gtk_widget_set_sensitive(lookup_widget(dialog, "pulse_buffer_size"), 0);
+#endif
 	
 	/* Audio: OSS */
 	append_oss_device_list(GTK_COMBO_BOX_TEXT(lookup_widget(dialog, "oss_audio_device")), globals.oss_device);
@@ -395,10 +390,8 @@ void init_tx_options(GtkWidget *dialog) {
 	
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(lookup_widget(dialog, "alsa_free_hwstats")), globals.alsa_free_hwstats);
 	
-	/* Input */
-	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(lookup_widget(dialog, "xinput_enable")), globals.xinput_enable);
-	
-	append_xinput_devices_list(GTK_COMBO_BOX_TEXT(lookup_widget(dialog, "xinput_device")), globals.xinput_device);
+	gtk_range_set_value(GTK_RANGE(lookup_widget(dialog, "pulse_buffer_size")), globals.pulse_buffer_length);
+	gtk_widget_set_tooltip_text(lookup_widget(dialog, "pulse_buffer_size"), "Sets the requested buffer size for PulseAudio in samples (per channel). Lower values should result in lower latency, however PulseAudio may override this setting.");	
 
 	gtk_range_set_value(GTK_RANGE(lookup_widget(dialog, "mouse_speed")), globals.mouse_speed);
 	gtk_widget_set_tooltip_text(lookup_widget(dialog, "mouse_speed"), "The speed of your mouse in scratch mode. Use negative values to invert motion.");
@@ -436,6 +429,16 @@ void init_tx_options(GtkWidget *dialog) {
 	gtk_range_set_value(GTK_RANGE(lookup_widget(dialog, "vumeter_decay")), globals.flash_response);
 	gtk_widget_set_tooltip_text(lookup_widget(dialog, "vumeter_decay"), "Defines how fast the maximum values of the VU meters should be decayed.");	
 
+
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(lookup_widget(dialog, "override_knob_size")), globals.knob_size_override > 0);
+	if (globals.knob_size_override) {
+		gtk_range_set_value(GTK_RANGE(lookup_widget(dialog, "knob_size")), globals.knob_size_override);
+	} else {
+		gtk_range_set_value(GTK_RANGE(lookup_widget(dialog, "knob_size")), 48);
+	}
+	
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(lookup_widget(dialog, "wav_display_history")), globals.wav_display_history);
+
 	/* Audio Colors */
 	int ctr=0;
 	
@@ -466,7 +469,7 @@ void init_tx_options(GtkWidget *dialog) {
 
 void create_options()
 {
-	opt_dialog=create_tx_options();
+	opt_dialog=create_tx_options(GTK_WINDOW(main_window));
 	tX_set_icon(opt_dialog);
 	init_tx_options(opt_dialog);
 	gtk_widget_show(opt_dialog);
@@ -503,8 +506,6 @@ void destroy_about()
 #define add_about_wid_fix(wid); gtk_box_pack_start(GTK_BOX(box), wid, WID_FIX); \
 	gtk_widget_show(wid);
 
-GdkFont *GPL_font=NULL;
-
 void show_about(int nag)
 {
 	GtkWidget *window;
@@ -535,22 +536,22 @@ void show_about(int nag)
 	iwid = gtk_image_new_from_pixbuf(image);
 	
 	if (nag) {
-		GtkWidget *box=gtk_vbox_new(FALSE, 2);
-		GtkWidget *box2=gtk_hbox_new(FALSE, 2);
+		GtkWidget *box=gtk_box_new(GTK_ORIENTATION_VERTICAL, 2);
+		GtkWidget *box2=gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 2);
 		GtkWidget *label;
 		
 		gtk_container_add(GTK_CONTAINER(window), box);
 		gtk_box_pack_start(GTK_BOX(box), iwid, WID_FIX);
 		gtk_box_pack_start(GTK_BOX(box), box2, WID_FIX);
 		
-		label=gtk_label_new(PACKAGE" release "VERSION);
+		label=gtk_label_new(PACKAGE " release " VERSION);
 		gtk_box_pack_start(GTK_BOX(box2), label, WID_DYN);
-		gtk_misc_set_alignment(GTK_MISC(label), 0.1, 0.5);
+		gtk_widget_set_halign(label, GTK_ALIGN_START);
 		gtk_widget_show(label);
 
-		label=gtk_label_new("Copyright (C) 1999-2014 by Alexander König");
+		label=gtk_label_new("Copyright (C) 1999-2016 by Alexander König");
 		gtk_box_pack_start(GTK_BOX(box2), label, WID_DYN);
-		gtk_misc_set_alignment(GTK_MISC(label), 0.9, 0.5);
+		gtk_widget_set_halign(label, GTK_ALIGN_END);
 		gtk_widget_show(label);
 		
 		gtk_widget_show(box2);
@@ -560,22 +561,22 @@ void show_about(int nag)
 		gtk_window_set_decorated(GTK_WINDOW(window), FALSE);		
 		gtk_widget_show(window);
 	} else {
-		box=gtk_vbox_new(FALSE, 5);
+		box=gtk_box_new(GTK_ORIENTATION_VERTICAL, 5);
 		add_about_wid_fix(iwid);
 		
-		sep=gtk_hseparator_new();
+		sep=gtk_separator_new(GTK_ORIENTATION_HORIZONTAL);
 		add_about_wid_fix(sep);
 		
-		label=gtk_label_new("This is "PACKAGE" release "VERSION".\nCopyright (C) 1999-2014 by Alexander König <alex@lisas.de>");
+		label=gtk_label_new("This is " PACKAGE " release " VERSION ".\nCopyright (C) 1999-2016 by Alexander König <alex@lisas.de>");
 
 		gtk_label_set_justify(GTK_LABEL(label), GTK_JUSTIFY_CENTER);
 		add_about_wid_fix(label);
 
-		sep=gtk_hseparator_new();
+		sep=gtk_separator_new(GTK_ORIENTATION_HORIZONTAL);
 		add_about_wid_fix(sep);
 
 		expander = gtk_expander_new("Build info");
-		GtkWidget *exbox=gtk_vbox_new(FALSE, 2);
+		GtkWidget *exbox=gtk_box_new(GTK_ORIENTATION_VERTICAL, 2);
 		gtk_container_add(GTK_CONTAINER(expander), exbox);
 		gtk_widget_show(exbox);
 
@@ -598,6 +599,7 @@ void show_about(int nag)
 #ifdef USE_AUDIOFILE_INPUT
 		" [audiofile]"
 #endif
+		"\n"
 #ifdef USE_ALSA_MIDI_IN
 		" [midi]"
 #endif
@@ -610,6 +612,9 @@ void show_about(int nag)
 #ifdef USE_JACK
 		" [jack]"
 #endif
+#ifdef USE_PULSE
+		" [pulse]"
+#endif
 #ifdef USE_LRDF
 		" [lrdf]"
 #endif
@@ -629,7 +634,7 @@ void show_about(int nag)
 		add_about_wid_fix(expander);
 
 #ifdef 	USE_SCHEDULER
-		sep=gtk_hseparator_new();
+		sep=gtk_separator_new(GTK_ORIENTATION_HORIZONTAL);
 		gtk_widget_show(sep);
 		gtk_container_add(GTK_CONTAINER(exbox), sep);
 
@@ -657,7 +662,7 @@ void show_about(int nag)
 				break;
 			
 			default:
-				sprintf(prio_str, "UNKOWN (%i)", policy);
+				sprintf(prio_str, "UNKNOWN (%i)", policy);
 		}
 		
 		sprintf(buffer, "Audio engine scheduling policy: %s.\nScheduling with realtime priority is %s.", prio_str, s_enabled ? "enabled" : "disabled");
@@ -669,7 +674,7 @@ void show_about(int nag)
 		gtk_container_add(GTK_CONTAINER(exbox), label);
 #endif
 
-		sep=gtk_hseparator_new();
+		sep=gtk_separator_new(GTK_ORIENTATION_HORIZONTAL);
 		add_about_wid_fix(sep);
 
 		expander = gtk_expander_new("License (GPL V2):");
@@ -693,13 +698,13 @@ void show_about(int nag)
 		gtk_text_buffer_insert_with_tags_by_name(tbuffer, &iter, license, -1, "courier", NULL);
 		gtk_text_view_set_left_margin(GTK_TEXT_VIEW(text), 5);
 		gtk_text_view_set_right_margin(GTK_TEXT_VIEW(text), 5);
-		gtk_widget_set_size_request(GTK_WIDGET(text), 640, 200);
+		gtk_widget_set_size_request(GTK_WIDGET(scroll), 640, 200);
 		gtk_widget_show(text);		
 		
 		gtk_container_add(GTK_CONTAINER(expander), scroll);
 		gtk_widget_show(scroll);		
 		
-		sep=gtk_hseparator_new();
+		sep=gtk_separator_new(GTK_ORIENTATION_HORIZONTAL);
 		add_about_wid_fix(sep);
 
 		btn=gtk_button_new_with_label("Close");
@@ -724,7 +729,15 @@ static GdkPixbuf *tX_window_icon=NULL;
 void tX_set_icon(GtkWidget *widget)
 {	
 	if (!tX_window_icon) {
-		tX_window_icon=gdk_pixbuf_new_from_inline(-1, tX_icon, FALSE, NULL);
+		GError *error = NULL;
+		g_resource_new_from_data(g_bytes_new_static(tX_dialog_resource_data.data, sizeof(tX_dialog_resource_data.data)), &error);
+		if (error) {
+		    tX_error("Error accesing tX_dialog resources: %s", error->message);
+		}
+		tX_window_icon=gdk_pixbuf_new_from_resource("/org/terminatorX/tX_dialog/../../icons/terminatorX.png", &error);
+		if (error) {
+		    tX_error("Error rendering tX icon: %s", error->message);
+		}
 	}
 
 	gtk_window_set_icon(GTK_WINDOW(widget), tX_window_icon);
