@@ -1,6 +1,6 @@
 /*
     terminatorX - realtime audio scratching software
-    Copyright (C) 1999-2014  Alexander König
+    Copyright (C) 1999-2016  Alexander König
  
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -205,23 +205,29 @@ tX_engine_error tX_engine :: run() {
 #ifdef USE_OSS	
 		case OSS:
 			device=new tX_audiodevice_oss(); 
-		break;
+			break;
 #endif			
 
 #ifdef USE_ALSA			
 		case ALSA:
 			device=new tX_audiodevice_alsa(); 
-		break;
+			break;
 #endif
 
 #ifdef USE_JACK
 		case JACK:
 			device=new tX_audiodevice_jack();
-		break;
+			break;
+#endif
+
+#ifdef USE_PULSE
+		case PULSE:
+			device=new tX_audiodevice_pulse();
+			break;
 #endif
 		
 		default:
-			device=NULL; return ERROR_AUDIO;
+			device=NULL; return ERROR_BACKEND;
 	}
 	
 	if (device->open()) {
