@@ -1,6 +1,6 @@
 /*
     terminatorX - realtime audio scratching software
-    Copyright (C) 1999-2014  Alexander König
+    Copyright (C) 1999-2016  Alexander König
  
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -59,18 +59,25 @@ tX_extdial :: tX_extdial(const char *l, GtkAdjustment *a, tX_seqpar * sp, bool t
 	ignore_adj=0;
 	
 	eventbox=gtk_event_box_new();		
-	mainbox=gtk_vbox_new(FALSE,  text_below ? 5 : 0);
+	mainbox=gtk_box_new(GTK_ORIENTATION_VERTICAL,  text_below ? 5 : 0);
+	
 	gtk_container_add(GTK_CONTAINER(eventbox), mainbox);
 	
-	subbox=gtk_hbox_new(TRUE, 0);
+	subbox=gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
+	gtk_box_set_homogeneous(GTK_BOX(subbox), TRUE);
 	gtk_box_pack_start(GTK_BOX(subbox), dial, WID_FIX);
 	gtk_box_pack_start(GTK_BOX(mainbox), subbox, WID_FIX);
-	gtk_box_pack_start(GTK_BOX(text_below ? mainbox : subbox), entry, WID_DYN);
+	if (text_below) {
+		gtk_box_pack_start(GTK_BOX(mainbox), entry, WID_DYN);
+	} else {
+		gtk_box_pack_start(GTK_BOX(subbox), entry, TRUE, TRUE, 3);
+	}
 	if (l) gtk_box_pack_start(GTK_BOX(mainbox), label, WID_FIX);
 	
 	if (l) gtk_widget_show(label);
 	if (!hide_entry){ gtk_widget_show(entry); }
 	gtk_entry_set_width_chars(GTK_ENTRY(entry), 4);
+	gtk_entry_set_max_width_chars(GTK_ENTRY(entry), 4);
 	gtk_widget_show(dial);
 	gtk_widget_show(subbox);
 	gtk_widget_show(mainbox);
@@ -88,7 +95,6 @@ tX_extdial :: tX_extdial(const char *l, GtkAdjustment *a, tX_seqpar * sp, bool t
 
 tX_extdial :: ~tX_extdial()
 {
-	gtk_object_destroy(GTK_OBJECT(adj));
 	gtk_widget_destroy(entry);
 	gtk_widget_destroy(label);
 	gtk_widget_destroy(dial);
