@@ -1,6 +1,6 @@
 /*
     terminatorX - realtime audio scratching software
-    Copyright (C) 1999-2014  Alexander König
+    Copyright (C) 1999-2016  Alexander König
  
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -79,7 +79,9 @@ void set_global_defaults() {
 	globals.alsa_buffer_time=80000;
 	globals.alsa_period_time=20000;
 	globals.alsa_samplerate=44100;
-	
+
+	globals.pulse_buffer_length=320;
+
 	globals.sense_cycles=80;
 	
 	globals.mouse_speed=0.8;
@@ -93,6 +95,7 @@ void set_global_defaults() {
 	globals.use_stdout_from_conf_file=0;
 	
 	globals.show_nag=1;
+	globals.input_fallback_warning=1;
 	globals.prelis=1;
 	
 	strcpy(globals.last_fn,"");
@@ -102,6 +105,7 @@ void set_global_defaults() {
 	globals.gui_wrap=3;
 	
 	globals.flash_response=0.95;
+	globals.knob_size_override=0;
 	
 	globals.button_type=BUTTON_TYPE_BOTH;
 		
@@ -110,14 +114,18 @@ void set_global_defaults() {
 	strcpy(globals.tables_filename, "");
 	strcpy(globals.record_filename, "tX_record.wav");
 	strcpy(globals.file_editor, "");
-		
+
+#ifdef USE_PULSE
+	globals.audiodevice_type=PULSE;
+#else	
 #ifdef USE_ALSA
 	globals.audiodevice_type=ALSA;
 #else
 #ifdef USE_OSS
 	globals.audiodevice_type=OSS;
 #endif	
-#endif		
+#endif	
+#endif
 	globals.use_stdout_cmdline=0;
 	strcpy(globals.current_path, "");
 	strcpy(globals.lrdf_path, "/usr/share/ladspa/rdf:/usr/local/share/ladspa/rdf");
@@ -130,7 +138,9 @@ void set_global_defaults() {
 	globals.alsa_free_hwstats=0;
 	globals.filename_length=20;
 	globals.restore_midi_connections=1;
-	
+
+	globals.wav_display_history=1;
+
 	strcpy(globals.wav_display_bg_focus, "#00004C");
 	strcpy(globals.wav_display_bg_no_focus, "#000000");
 
@@ -203,6 +213,8 @@ int load_globals_xml() {
 			restore_int("alsa_samplerate", globals.alsa_samplerate);
 			restore_int("alsa_free_hwstats", globals.alsa_free_hwstats);
 			
+			restore_int("pulse_buffer_length", globals.pulse_buffer_length);
+
 			restore_string("xinput_device", globals.xinput_device);
 			restore_int("xinput_enable", globals.xinput_enable);
 			restore_int("update_idle", globals.update_idle);
@@ -215,11 +227,13 @@ int load_globals_xml() {
 			restore_int("tooltips", globals.tooltips);
 			restore_int("use_stdout", globals.use_stdout);
 			restore_int("show_nag", globals.show_nag);
+			restore_int("input_fallback_warning", globals.input_fallback_warning);
 			restore_int("prelis", globals.prelis);
 			restore_string("last_fn", globals.last_fn);
 			restore_float("pitch", globals.pitch);
 			restore_float("volume", globals.volume);
 			restore_float("flash_response", globals.flash_response);
+			restore_int("knob_size_override", globals.knob_size_override);
 			restore_int("button_type", globals.button_type);
 			restore_string("tables_filename", globals.tables_filename);
 			restore_string("record_filename", globals.record_filename);
@@ -232,7 +246,8 @@ int load_globals_xml() {
 			restore_int("confirm_events", globals.confirm_events);
 			restore_float("vtt_inertia", globals.vtt_inertia);
 			restore_int("restore_midi_connections", globals.restore_midi_connections);
-			
+
+			restore_int("wav_display_history", globals.wav_display_history);
 			restore_string("wav_display_bg_focus", globals.wav_display_bg_focus);
 			restore_string("wav_display_bg_no_focus", globals.wav_display_bg_no_focus);
 			restore_string("wav_display_fg_focus", globals.wav_display_fg_focus);
@@ -269,8 +284,9 @@ int load_globals_xml() {
 
 	xmlFreeDoc(doc);
 	
-	if (strcmp(device_type, "alsa")==0) globals.audiodevice_type=ALSA;
-	else if (strcmp(device_type, "jack")==0) globals.audiodevice_type=JACK;
+	if (strcmp(device_type, "alsa")==0) { globals.audiodevice_type=ALSA; }
+	else if (strcmp(device_type, "jack")==0) { globals.audiodevice_type=JACK; }
+	else if (strcmp(device_type, "pulse")==0) { globals.audiodevice_type=PULSE; }
 	else globals.audiodevice_type=OSS;
 	
 	return 0;
@@ -290,6 +306,9 @@ void store_globals() {
 	rc=fopen(rc_name, "w");
 	
 	switch (globals.audiodevice_type) {
+		case PULSE:
+			strcpy(device_type, "pulse");
+			break;
 		case JACK:
 			strcpy(device_type, "jack");
 			break;
@@ -321,6 +340,8 @@ void store_globals() {
 		store_int("alsa_samplerate", globals.alsa_samplerate);		
 		store_int("alsa_free_hwstats", globals.alsa_free_hwstats);
 		
+		store_int("pulse_buffer_length", globals.pulse_buffer_length);
+
 		store_string("xinput_device", globals.xinput_device);
 		store_int("xinput_enable", globals.xinput_enable);
 		store_int("update_idle", globals.update_idle);
@@ -334,11 +355,13 @@ void store_globals() {
 		store_int("use_stdout", globals.use_stdout);
 		// globals.use_stdout_from_conf_file=0; What the heck is this?
 		store_int("show_nag", globals.show_nag);
+		store_int("input_fallback_warning", globals.input_fallback_warning);
 		store_int("prelis", globals.prelis);
 		store_string("last_fn", globals.last_fn);
 		store_float("pitch", globals.pitch);
 		store_float("volume", globals.volume);
 		store_float("flash_response", globals.flash_response);
+		store_int("knob_size_override", globals.knob_size_override);
 		store_int("button_type", globals.button_type);
 		store_string("tables_filename", globals.tables_filename);
 		store_string("record_filename", globals.record_filename);
@@ -352,6 +375,7 @@ void store_globals() {
 		store_string("last_path", globals.current_path);
 		store_int("restore_midi_connections", globals.restore_midi_connections);
 
+		store_int("wav_display_history", globals.wav_display_history);
 		store_string("wav_display_bg_focus", globals.wav_display_bg_focus);
 		store_string("wav_display_bg_no_focus", globals.wav_display_bg_no_focus);
 		store_string("wav_display_fg_focus", globals.wav_display_fg_focus);
