@@ -1,6 +1,6 @@
 /*
     terminatorX - realtime audio scratching software
-    Copyright (C) 1999-2014  Alexander König
+    Copyright (C) 1999-2016  Alexander König
  
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -61,6 +61,9 @@ extern "C" {
 #define tX_msg(fmt, args...); { fprintf(stderr, "- tX_msg: "); fprintf(stderr, fmt , ## args); fprintf(stderr, "\n"); }
 #define tX_plugin_warning(fmt, args...); { if (globals.verbose_plugin_loading) { fprintf(stderr, "+ tX_warning: "); fprintf(stderr, fmt , ## args); fprintf(stderr, "\n"); }}
 
+#define tX_min(a,b) ((a) < (b) ? (a) : (b))
+#define tX_max(a,b) ((a) > (b) ? (a) : (b))
+	
 #ifdef MEM_DEBUG
 #define tX_freemem(ptr, varname, comment); fprintf(stderr, "** free() [%s] at %08x. %s.\n", varname, ptr, comment); free(ptr);
 #define tX_malloc(ptr, varname, comment, size, type); fprintf(stderr, "**[1/2] malloc() [%s]. Size: %i. %s.\n", varname, size, comment); ptr=type malloc(size); fprintf(stderr, "**[2/2] malloc() [%s]. ptr: %08x.\n", varname, ptr);
@@ -72,7 +75,8 @@ extern "C" {
 typedef enum {
 	OSS =0,
 	ALSA = 1,
-	JACK = 2
+	JACK = 2,
+	PULSE = 3
 } tX_audiodevice_type;
 	
 typedef struct {
@@ -100,6 +104,7 @@ typedef struct {
 	int use_stdout_cmdline;
 	int use_stdout_from_conf_file;
 	int show_nag;
+	int input_fallback_warning;
 	
 	int prelis;
 	
@@ -113,9 +118,10 @@ typedef struct {
 	int autoname;
 	
 	float flash_response;
+	int knob_size_override;
 	
 	int button_type;
-	
+
 	char file_editor[PATH_MAX];
 	int true_block_size;
 	int update_delay; 
@@ -141,7 +147,10 @@ typedef struct {
 	int alsa_buffer_time;
 	int alsa_period_time;
 	int alsa_samplerate;
-	
+
+	/* PULSE specific options */
+	int pulse_buffer_length;
+
 	char lrdf_path[PATH_MAX];
 	
 	int compress_set_files;
@@ -155,6 +164,7 @@ typedef struct {
 	int filename_length;
 	
 	int restore_midi_connections;
+	int wav_display_history;
 	
 	char wav_display_bg_focus[8];
 	char wav_display_bg_no_focus[8];
