@@ -1,6 +1,6 @@
 /*
     terminatorX - realtime audio scratching software
-    Copyright (C) 1999-2014  Alexander König
+    Copyright (C) 1999-2016  Alexander König
  
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -24,7 +24,6 @@
 #define _tX_knobloader_ 1
 
 #include <gtk/gtk.h>
-#include "icons/knobs.pixbuf"
 
 #ifdef HAVE_CONFIG_H
 #include <config.h>
@@ -40,15 +39,11 @@ extern "C" {
 #define MAX_KNOB_PIX 50
 #define TX_MAX_KNOB_PIX 49
 
-#ifdef USE_BIG_BUTTONS
-#define KNOB_SIZE 51
-#else
-#define KNOB_SIZE 42
-#endif
+extern int tX_knob_size;
 
 extern GdkPixbuf *knob_pixmaps[MAX_KNOB_PIX];
 	
-extern void load_knob_pixs();
+extern void load_knob_pixs(int fontHeight, int scaleFactor);
 
 #ifdef __cplusplus
 }
