@@ -1,6 +1,6 @@
 /*
     terminatorX - realtime audio scratching software
-    Copyright (C) 1999-2014  Alexander König
+    Copyright (C) 1999-2016  Alexander König
  
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -54,7 +54,7 @@ gfloat ld_old_prog;
 
 int ld_create_loaddlg(int mode, int count)
 {
-	GtkWidget *vbox=gtk_vbox_new(0, 5);
+	GtkWidget *vbox=gtk_box_new(GTK_ORIENTATION_VERTICAL, 5);
 	GtkWidget *dummy;
 	
 	if (ld_loaddlg) return 1;
@@ -74,13 +74,12 @@ int ld_create_loaddlg(int mode, int count)
 	
 	if (mode==TX_LOADDLG_MODE_MULTI) {
 		ld_multi_l=gtk_label_new("Loading Set");
-		gtk_misc_set_alignment(GTK_MISC(ld_multi_l), 0.5, 0.5);
 		add_widget_fix(ld_multi_l);
 		
 		ld_multi_p=gtk_progress_bar_new();
 		add_widget_fix(ld_multi_p);
 		
-		dummy=gtk_hseparator_new();
+		dummy=gtk_separator_new(GTK_ORIENTATION_HORIZONTAL);
 		add_widget_fix(dummy);
 		
 		ld_current=0;
