@@ -1,6 +1,6 @@
 /*
     terminatorX - realtime audio scratching software
-    Copyright (C) 1999-2014  Alexander König
+    Copyright (C) 1999-2016  Alexander König
  
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -23,7 +23,7 @@
 
 #include <gtk/gtk.h>
 #include <gdk/gdkx.h>
-#include <X11/Xlib.h>
+#include <pango/pango.h>
 #include <math.h>
 #include <unistd.h>
 #include <string.h>
@@ -52,6 +52,10 @@
 #include <sys/resource.h>
 #endif
 
+#ifdef USE_X11
+#include <X11/Xlib.h>
+#endif
+
 #define TX_SET_ID_10 "terminatorX turntable set file - version 1.0 - data:"
 #define TX_SET_ID_11 "terminatorX turntable set file - version 1.1 - data:"
 #define TX_SET_ID_12 "terminatorX turntable set file - version 1.2 - data:"
@@ -64,6 +68,7 @@
 
 int audioon=0;
 int sequencer_ready=1;
+int fontHeight=16;
 
 bool tX_shutdown=false;
 tx_mouse mouse;
@@ -99,7 +104,6 @@ GtkWidget *engine_btn;
 
 GtkWidget *main_menubar;
 GtkWidget *rec_menu_item;
-GtkWidget *fullscreen_item;
 
 int rec_dont_care=0;
 gint update_tag;
@@ -108,21 +112,17 @@ gint update_tag;
 #define connect_adj(wid, func, ptr); g_signal_connect(G_OBJECT(wid), "value_changed", (GCallback) func, (void *) ptr);
 #define connect_button(wid, func, ptr); g_signal_connect(G_OBJECT(wid), "clicked", (GCallback) func, (void *) ptr);
 
+#ifdef USE_X11
 Window x_window;
+GtkWidget *fullscreen_item;
+#endif
+
 GdkWindow* top_window;
 #define WID_DYN TRUE, TRUE, 0
 #define WID_FIX FALSE, FALSE, 0
 extern void add_vtt(GtkWidget *ctrl, GtkWidget *audio, char *fn);
 extern void destroy_gui(vtt_class *vtt);
-extern void gui_show_frame(vtt_class *vtt, int show);
-
-#ifndef USE_FILECHOOSER
-GdkWindow *save_dialog_win=NULL;
-GdkWindow *load_dialog_win=NULL;
-
-GtkWidget *save_dialog=NULL;
-GtkWidget *load_dialog=NULL;
-#endif
+extern void gui_show_focus(vtt_class *vtt, int show);
 
 GdkWindow *rec_dialog_win=NULL;
 GtkWidget *rec_dialog=NULL;
@@ -161,7 +161,7 @@ gint pos_update(gpointer data)
 	if (stop_update) {		
 		cleanup_all_vtts();
 		tX_seqpar :: update_all_graphics();
-		if (old_focus) gui_show_frame(old_focus, 0);
+		if (old_focus) gui_show_focus(old_focus, 0);
 		old_focus=NULL;
 		gtk_tx_flash_clear(main_flash);
 		gdk_flush();	
@@ -178,9 +178,9 @@ gint pos_update(gpointer data)
 		gtk_tx_flash_set_level(main_flash, temp/FL_SHRT_MAX, temp2/FL_SHRT_MAX);
 
 		if (vtt_class::focused_vtt!=old_focus) {
-			if (old_focus) gui_show_frame(old_focus, 0);
+			if (old_focus) gui_show_focus(old_focus, 0);
 			old_focus=vtt_class::focused_vtt;
-			if (old_focus) gui_show_frame(old_focus, 1);			
+			if (old_focus) gui_show_focus(old_focus, 1);			
 		}
 
 		grab_status = mouse.is_grabbed();
@@ -294,16 +294,6 @@ GCallback new_tables() {
 }
 
 /* Loading saved setups */
-#ifndef USE_FILECHOOSER
-GCallback cancel_load_tables(GtkWidget *wid)
-{
-	gtk_widget_destroy(load_dialog);
-	load_dialog=NULL;
-	load_dialog_win=NULL;
-	return(0);
-}
-#endif
-
 void load_tt_part(char * buffer)
 {
 	char wbuf[PATH_MAX];
@@ -378,31 +368,12 @@ void load_tt_part(char * buffer)
 	gtk_window_set_title(GTK_WINDOW(main_window), wbuf);		
 }
 
-#ifndef USE_FILECHOOSER
-void do_load_tables(GtkWidget *wid)
-{
-	char buffer[PATH_MAX];
-	
-	strcpy(buffer, gtk_file_selection_get_filename(GTK_FILE_SELECTION(load_dialog)));
-	
-	gtk_widget_destroy(load_dialog);
-	
-	load_dialog=NULL;
-	load_dialog_win=NULL;
-
-	tX_cursor::set_cursor(tX_cursor::WAIT_CURSOR);
-	load_tt_part(buffer);
-	tX_cursor::reset_cursor();
-}
-#endif
-
 GCallback load_tables()
 {
-#ifdef USE_FILECHOOSER	
 	GtkWidget * dialog = gtk_file_chooser_dialog_new ("Open Set File",
 		GTK_WINDOW(main_window), GTK_FILE_CHOOSER_ACTION_OPEN,
-		GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,  
-	    GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT, NULL);
+		"_Cancel", GTK_RESPONSE_CANCEL,  
+	    "_Open", GTK_RESPONSE_ACCEPT, NULL);
 				      
 
 	GtkFileFilter *filter=gtk_file_filter_new();
@@ -429,38 +400,14 @@ GCallback load_tables()
 	}	
 	
 	gtk_widget_destroy(dialog);
-#else
-	if (load_dialog_win) {
-		gdk_window_raise(load_dialog_win);
-		return 0;
-	}
-
-	load_dialog=gtk_file_selection_new("Load Set");	
-	
-	gtk_file_selection_show_fileop_buttons(GTK_FILE_SELECTION(load_dialog));
-	gtk_file_selection_complete(GTK_FILE_SELECTION(load_dialog), "*.tX");
-	
-	if (strlen(globals.tables_filename)) {
-		gtk_file_selection_set_filename(GTK_FILE_SELECTION(load_dialog), globals.tables_filename);
-	}
-	
-	gtk_widget_show(load_dialog);
-	
-	load_dialog_win=load_dialog->window;
-	
-	g_signal_connect (G_OBJECT(GTK_FILE_SELECTION(load_dialog)->ok_button), "clicked", G_CALLBACK(do_load_tables), NULL);
-	g_signal_connect (G_OBJECT(GTK_FILE_SELECTION(load_dialog)->cancel_button), "clicked", G_CALLBACK (cancel_load_tables), NULL);	
-	g_signal_connect (G_OBJECT(load_dialog), "delete-event", G_CALLBACK(cancel_load_tables), NULL);	
-	
-#endif
 
 	return NULL;
 }
 
 vtt_class* choose_vtt() {
 	GtkWidget *dialog = gtk_dialog_new_with_buttons("Select Turntable",
-		GTK_WINDOW(main_window), GTK_DIALOG_MODAL, GTK_STOCK_CANCEL, GTK_RESPONSE_REJECT,
-		GTK_STOCK_OK, GTK_RESPONSE_ACCEPT, NULL);	
+		GTK_WINDOW(main_window), GTK_DIALOG_MODAL, "_Cancel", GTK_RESPONSE_REJECT,
+		"_OK", GTK_RESPONSE_ACCEPT, NULL);	
 
 	GtkWidget *label = gtk_label_new ("Select turntable to load audio file to:");
 	gtk_widget_show(label);
@@ -554,39 +501,6 @@ GCallback drop_set(GtkWidget *widget, GdkDragContext *context,
 }
 
 /* save tables */
-
-#ifndef USE_FILECHOOSER
-GCallback cancel_save_tables(GtkWidget *wid)
-{
-	gtk_widget_destroy(save_dialog);
-	save_dialog=NULL;
-	save_dialog_win=NULL;
-	return(0);
-}
-
-gboolean do_save_from_selection(GtkWidget *wid) {
-	char buffer[PATH_MAX];
-	
-	if (wid) {
-		strcpy(buffer, gtk_file_selection_get_filename(GTK_FILE_SELECTION(save_dialog)));
-		int len=strlen(buffer);
-		if (!len || (buffer[len-1]=='/')) {			
-			tx_note("Invalid filename for set file.", true);			
-			return FALSE;
-		}
-		gtk_widget_destroy(save_dialog);
-		save_dialog=NULL;
-		save_dialog_win=NULL;
-	} else {
-		strcpy(buffer, tx_mg_current_setname);
-	}	
-	
-	do_save_tables(buffer);
-	
-	return TRUE;
-}
-#endif
-
 void do_save_tables(char *buffer)
 {
 	FILE *out;
@@ -629,11 +543,10 @@ void do_save_tables(char *buffer)
 
 GCallback save_tables_as()
 {
-#ifdef USE_FILECHOOSER
 	GtkWidget * dialog = gtk_file_chooser_dialog_new ("Save Set",
 		GTK_WINDOW(main_window), GTK_FILE_CHOOSER_ACTION_SAVE, 
-		GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL, 
-		GTK_STOCK_SAVE, GTK_RESPONSE_ACCEPT,NULL);
+		"_Cancel", GTK_RESPONSE_CANCEL, 
+		"_Save", GTK_RESPONSE_ACCEPT,NULL);
 	
 	if (tx_mg_have_setname) {
 		gtk_file_chooser_set_filename(GTK_FILE_CHOOSER (dialog), tx_mg_current_setname);
@@ -648,27 +561,7 @@ GCallback save_tables_as()
 	}	
 	
 	gtk_widget_destroy(dialog);	
-#else
-	if (save_dialog_win) {
-		gtk_widget_destroy(save_dialog);
-		save_dialog=NULL;
-		save_dialog_win=NULL;
-	}
-	
-	save_dialog=gtk_file_selection_new("Save Set");	
 
-	if (tx_mg_have_setname) {
-		gtk_file_selection_set_filename(GTK_FILE_SELECTION(save_dialog), tx_mg_current_setname);
-	}
-	
-	gtk_widget_show(save_dialog);
-	
-	save_dialog_win=save_dialog->window;
-	
-	g_signal_connect (G_OBJECT(GTK_FILE_SELECTION(save_dialog)->ok_button), "clicked", G_CALLBACK(do_save_from_selection), NULL);
-	g_signal_connect (G_OBJECT(GTK_FILE_SELECTION(save_dialog)->cancel_button), "clicked", G_CALLBACK (cancel_save_tables), NULL);	
-	g_signal_connect (G_OBJECT(save_dialog), "delete-event", G_CALLBACK(cancel_save_tables), NULL);	
-#endif
 	return NULL;
 }
 
@@ -734,6 +627,30 @@ GCallback audio_on(GtkWidget *w, void *d)
 				case ERROR_AUDIO:
 				tx_note("Error starting engine: failed to access audiodevice.\nPlease check the audio device settings in the \"Preferences\" dialog.", true);
 				break;
+				case ERROR_BACKEND:
+				char audio_backend[256];
+				char message[4096];
+
+				switch (globals.audiodevice_type) {
+				    case OSS:
+				    	strcpy(audio_backend, "the Open Sound System (OSS)");
+				    	break;
+				    case ALSA:
+				    	strcpy(audio_backend, "the Advanced Linux Sound Architecture (ALSA)");
+				    	break;
+				    case JACK:
+				    	strcpy(audio_backend, "the JACK Audio Connection Kit");
+				    	break;
+				    case PULSE:
+				    	strcpy(audio_backend, "PulseAudio");
+				    	break;
+				    default:
+					strcpy(audio_backend, "unkown");
+				}
+
+				sprintf(message,"Error starting engine: couldn't start audio driver.\nThis terminatorX binary was compiled without support for %s.\nPlease check the audio device settings in the \"Preferences\" dialog.", audio_backend);
+				tx_note(message, true);
+				break;
 				case ERROR_TAPE:
 				tx_note("Error starting engine: failed to open the recording file.", true);
 				break;
@@ -808,11 +725,10 @@ void do_rec(GtkWidget *wid)
 
 GCallback select_rec_file()
 {
-#ifdef USE_FILECHOOSER
 	GtkWidget * dialog = gtk_file_chooser_dialog_new ("Record To Disk",
 		GTK_WINDOW(main_window), GTK_FILE_CHOOSER_ACTION_SAVE, 
-		GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL, 
-		GTK_STOCK_SAVE, GTK_RESPONSE_ACCEPT,NULL);
+		"_Cancel", GTK_RESPONSE_CANCEL, 
+		"_Save", GTK_RESPONSE_ACCEPT,NULL);
 	
 	if (strlen(globals.record_filename)) {
 		gtk_file_chooser_set_filename(GTK_FILE_CHOOSER (dialog), globals.record_filename);
@@ -832,28 +748,6 @@ GCallback select_rec_file()
 	rec_dont_care = 0;
 	
 	gtk_widget_destroy(dialog);
-	
-#else	
-	if (rec_dialog_win) {
-		gdk_window_raise(rec_dialog_win);
-		return 0;
-	}
-	
-	rec_dialog=gtk_file_selection_new("Record To Disk");	
-	
-	if (strlen(globals.record_filename)) {
-		gtk_file_selection_set_filename(GTK_FILE_SELECTION(rec_dialog), globals.record_filename);
-	}
-	
-	gtk_widget_show(rec_dialog);
-	
-	rec_dialog_win=rec_dialog->window;
-	
-	g_signal_connect (G_OBJECT(GTK_FILE_SELECTION(rec_dialog)->ok_button), "clicked", G_CALLBACK(do_rec), NULL);
-	g_signal_connect (G_OBJECT(GTK_FILE_SELECTION(rec_dialog)->cancel_button), "clicked", G_CALLBACK (cancel_rec), NULL);	
-	g_signal_connect (G_OBJECT(rec_dialog), "delete-event", G_CALLBACK(cancel_rec), NULL);	
-	
-#endif
 
 	return NULL;
 }
@@ -1033,15 +927,18 @@ void sequencer_move(GtkWidget *wid, void *d)
 	}
 }
 
-#define add_sep(); 	dummy=gtk_hseparator_new ();\
+#define add_sep(); 	dummy=gtk_separator_new (GTK_ORIENTATION_HORIZONTAL);\
 	gtk_box_pack_start(GTK_BOX(right_hbox), dummy, WID_FIX);\
 	gtk_widget_show(dummy);\
 
-#define add_sep2(); 	dummy=gtk_hseparator_new ();\
+#define add_sep2(); 	dummy=gtk_separator_new (GTK_ORIENTATION_HORIZONTAL);\
 	gtk_box_pack_end(GTK_BOX(status_box), dummy, WID_FIX);\
 	gtk_widget_show(dummy);\
 
+#ifdef USE_X11
 void fullscreen_toggle(GtkCheckMenuItem *item, gpointer data);
+#endif
+
 void display_help();
 void display_browser();
 
@@ -1191,11 +1088,10 @@ void create_master_menu()
 {
 	GtkWidget *menu_item;
 	GtkWidget *sub_menu;
-	GtkWidget *label;
 	
 	GtkAccelGroup* accel_group=gtk_accel_group_new();
 	gtk_window_add_accel_group(GTK_WINDOW(main_window), accel_group);
-
+	
 	/* FILE */
 	menu_item = gtk_menu_item_new_with_mnemonic ("_File");
 	gtk_widget_show (menu_item);
@@ -1204,55 +1100,40 @@ void create_master_menu()
 	sub_menu = gtk_menu_new ();
 	gtk_menu_item_set_submenu (GTK_MENU_ITEM (menu_item), sub_menu);
 
-	menu_item = gtk_image_menu_item_new_from_stock ("gtk-open", accel_group);
-	label = gtk_bin_get_child(GTK_BIN(menu_item));
-	gtk_label_set_text(GTK_LABEL(label), "Load Audio File");
-	// Warning: gtk+ stock hacks ahead...
-	gtk_widget_remove_accelerator(menu_item, accel_group, GDK_O, GDK_CONTROL_MASK);
-	gtk_widget_add_accelerator (menu_item, "activate", accel_group, GDK_F, GDK_CONTROL_MASK, GTK_ACCEL_VISIBLE);
+	menu_item = gtk_menu_item_new_with_mnemonic("Load _Audio File");
 	gtk_widget_show (menu_item);
 	gtk_container_add (GTK_CONTAINER (sub_menu), menu_item);
 	g_signal_connect(menu_item, "activate", (GCallback) load_audio, NULL);
 
-	menu_item = gtk_menu_item_new ();
+	menu_item = gtk_separator_menu_item_new ();
 	gtk_widget_show (menu_item);
 	gtk_container_add (GTK_CONTAINER (sub_menu), menu_item);
-	gtk_widget_set_sensitive (menu_item, FALSE);
 
-	menu_item = gtk_image_menu_item_new_from_stock ("gtk-new", accel_group);
-	label = gtk_bin_get_child(GTK_BIN(menu_item));
-	gtk_label_set_text(GTK_LABEL(label), "New Set");
+	menu_item = gtk_menu_item_new_with_mnemonic("_New Set");
 	gtk_widget_show (menu_item);
 	gtk_container_add (GTK_CONTAINER (sub_menu), menu_item);
 	g_signal_connect(menu_item, "activate", (GCallback) new_tables, NULL);
 
-	menu_item = gtk_image_menu_item_new_from_stock ("gtk-open", accel_group);
-	label = gtk_bin_get_child(GTK_BIN(menu_item));
-	gtk_label_set_text(GTK_LABEL(label), "Open Set File");
+	menu_item = gtk_menu_item_new_with_mnemonic("_Open Set");
 	gtk_widget_show (menu_item);
 	gtk_container_add (GTK_CONTAINER (sub_menu), menu_item);
 	g_signal_connect(menu_item, "activate", (GCallback) load_tables, NULL);
 
-	menu_item = gtk_image_menu_item_new_from_stock ("gtk-save", accel_group);
-	label = gtk_bin_get_child(GTK_BIN(menu_item));
-	gtk_label_set_text(GTK_LABEL(label), "Save Set");
+	menu_item = gtk_menu_item_new_with_mnemonic("_Save Set");
 	gtk_widget_show (menu_item);
 	gtk_container_add (GTK_CONTAINER (sub_menu), menu_item);
 	g_signal_connect(menu_item, "activate", (GCallback) save_tables, NULL);
 
-	menu_item = gtk_image_menu_item_new_from_stock ("gtk-save-as", accel_group);
-	label = gtk_bin_get_child(GTK_BIN(menu_item));
-	gtk_label_set_text(GTK_LABEL(label), "Save Set As");
+	menu_item = gtk_menu_item_new_with_label("Save Set As");
 	gtk_widget_show (menu_item);
 	gtk_container_add (GTK_CONTAINER (sub_menu), menu_item);
 	g_signal_connect(menu_item, "activate", (GCallback) save_tables_as, NULL);
 
-	menu_item = gtk_menu_item_new ();
+	menu_item = gtk_separator_menu_item_new ();
 	gtk_widget_show (menu_item);
 	gtk_container_add (GTK_CONTAINER (sub_menu), menu_item);
-	gtk_widget_set_sensitive (menu_item, FALSE);
 
-	menu_item = gtk_image_menu_item_new_from_stock ("gtk-quit", accel_group);
+	menu_item = gtk_menu_item_new_with_mnemonic("_Quit");
 	gtk_widget_show (menu_item);
 	gtk_container_add (GTK_CONTAINER (sub_menu), menu_item);
 	g_signal_connect(menu_item, "activate", (GCallback) quit, NULL);
@@ -1268,18 +1149,17 @@ void create_master_menu()
 	menu_item = gtk_menu_item_new_with_mnemonic("_Add Turntable");
 	gtk_widget_show (menu_item);
 	gtk_container_add (GTK_CONTAINER (sub_menu), menu_item);
-	gtk_widget_add_accelerator (menu_item, "activate", accel_group, GDK_A, GDK_CONTROL_MASK, GTK_ACCEL_VISIBLE);	
+	gtk_widget_add_accelerator (menu_item, "activate", accel_group, GDK_KEY_A, GDK_CONTROL_MASK, GTK_ACCEL_VISIBLE);	
 	g_signal_connect(menu_item, "activate", (GCallback) new_table, NULL);
 
-	menu_item = gtk_menu_item_new ();
+	menu_item = gtk_separator_menu_item_new ();
 	gtk_widget_show (menu_item);
 	gtk_container_add (GTK_CONTAINER (sub_menu), menu_item);
-	gtk_widget_set_sensitive (menu_item, FALSE);
 
 	menu_item = gtk_menu_item_new_with_mnemonic("Assign _Default MIDI Mappings");
 	gtk_widget_show (menu_item);
 	gtk_container_add (GTK_CONTAINER (sub_menu), menu_item);
-	gtk_widget_add_accelerator (menu_item, "activate", accel_group, GDK_M, GDK_CONTROL_MASK, GTK_ACCEL_VISIBLE);
+	gtk_widget_add_accelerator (menu_item, "activate", accel_group, GDK_KEY_M, GDK_CONTROL_MASK, GTK_ACCEL_VISIBLE);
 
 #ifdef USE_ALSA_MIDI_IN
 	g_signal_connect(menu_item, "activate", G_CALLBACK(tX_midiin::auto_assign_midi_mappings), (void *) true);
@@ -1300,7 +1180,7 @@ void create_master_menu()
 	menu_item = gtk_menu_item_new_with_mnemonic("_Clear MIDI Mappings");
 	gtk_widget_show (menu_item);
 	gtk_container_add (GTK_CONTAINER (sub_menu), menu_item);
-	gtk_widget_add_accelerator (menu_item, "activate", accel_group, GDK_C, GDK_CONTROL_MASK, GTK_ACCEL_VISIBLE);
+	gtk_widget_add_accelerator (menu_item, "activate", accel_group, GDK_KEY_C, GDK_CONTROL_MASK, GTK_ACCEL_VISIBLE);
 
 #ifdef USE_ALSA_MIDI_IN
 	g_signal_connect(menu_item, "activate", G_CALLBACK(tX_midiin::clear_midi_mappings), (void *) true);
@@ -1308,14 +1188,13 @@ void create_master_menu()
 	gtk_widget_set_sensitive(menu_item, FALSE);
 #endif
 
-	menu_item = gtk_menu_item_new ();
+	menu_item = gtk_separator_menu_item_new ();
 	gtk_widget_show (menu_item);
 	gtk_container_add (GTK_CONTAINER (sub_menu), menu_item);
-	gtk_widget_set_sensitive (menu_item, FALSE);
 
 	menu_item = gtk_check_menu_item_new_with_mnemonic("_Record Audio To Disk");
 	rec_menu_item = menu_item;
-	gtk_widget_add_accelerator (menu_item, "activate", accel_group, GDK_R, GDK_CONTROL_MASK, GTK_ACCEL_VISIBLE);
+	gtk_widget_add_accelerator (menu_item, "activate", accel_group, GDK_KEY_R, GDK_CONTROL_MASK, GTK_ACCEL_VISIBLE);
 	gtk_widget_show (menu_item);
 	gtk_container_add (GTK_CONTAINER (sub_menu), menu_item);
 	g_signal_connect(menu_item, "activate", (GCallback) tape_on, NULL);
@@ -1345,10 +1224,9 @@ void create_master_menu()
 	gtk_container_add (GTK_CONTAINER (sub_menu), menu_item);
 	g_signal_connect(menu_item, "activate", (GCallback) menu_delete_all_events, NULL);
 
-	menu_item = gtk_menu_item_new ();
+	menu_item = gtk_separator_menu_item_new ();
 	gtk_widget_show (menu_item);
 	gtk_container_add (GTK_CONTAINER (sub_menu), menu_item);
-	gtk_widget_set_sensitive (menu_item, FALSE);
 
 	menu_item = gtk_check_menu_item_new_with_mnemonic("_Confirm Recorded Events");
 	//rec_menu_item = menu_item;
@@ -1364,22 +1242,24 @@ void create_master_menu()
 
 	sub_menu = gtk_menu_new ();
 	gtk_menu_item_set_submenu (GTK_MENU_ITEM (menu_item), sub_menu);
-		
+
 	menu_item = gtk_check_menu_item_new_with_mnemonic("_Fullscreen");
 	fullscreen_item = menu_item;
 	gtk_widget_show (menu_item);
 	gtk_container_add (GTK_CONTAINER (sub_menu), menu_item);
 
 	gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(menu_item), globals.fullscreen_enabled);
-	gtk_widget_add_accelerator (menu_item, "activate", accel_group, GDK_F11, (GdkModifierType) 0, GTK_ACCEL_VISIBLE);
+	gtk_widget_add_accelerator (menu_item, "activate", accel_group, GDK_KEY_F11, (GdkModifierType) 0, GTK_ACCEL_VISIBLE);
 	g_signal_connect(menu_item, "activate", (GCallback) fullscreen_toggle, NULL);
-	
-	menu_item = gtk_menu_item_new ();
+
+#ifndef USE_X11
+	gtk_widget_set_sensitive(menu_item, False);
+#endif
+	menu_item = gtk_separator_menu_item_new();
 	gtk_widget_show (menu_item);
 	gtk_container_add (GTK_CONTAINER (sub_menu), menu_item);
-	gtk_widget_set_sensitive (menu_item, FALSE);
 
-	menu_item = gtk_image_menu_item_new_from_stock ("gtk-preferences", accel_group);
+	menu_item = gtk_menu_item_new_with_mnemonic("_Preferences");
 	gtk_widget_show (menu_item);
 	gtk_container_add (GTK_CONTAINER (sub_menu), menu_item);
 	g_signal_connect(menu_item, "activate", (GCallback) display_options, NULL);
@@ -1388,7 +1268,6 @@ void create_master_menu()
 	menu_item = gtk_menu_item_new_with_mnemonic ("_Help");
 	gtk_widget_show (menu_item);
 	gtk_container_add (GTK_CONTAINER (main_menubar), menu_item);
-	gtk_menu_item_set_right_justified(GTK_MENU_ITEM(menu_item), TRUE);
 	
 	sub_menu = gtk_menu_new ();
 	gtk_menu_item_set_submenu (GTK_MENU_ITEM (menu_item), sub_menu);
@@ -1397,17 +1276,16 @@ void create_master_menu()
 	gtk_widget_show (menu_item);
 	gtk_container_add (GTK_CONTAINER (sub_menu), menu_item);
 	g_signal_connect(menu_item, "activate", (GCallback) display_help, NULL);
-	gtk_widget_add_accelerator (menu_item, "activate", accel_group, GDK_F1, (GdkModifierType) 0, GTK_ACCEL_VISIBLE);
+	gtk_widget_add_accelerator (menu_item, "activate", accel_group, GDK_KEY_F1, (GdkModifierType) 0, GTK_ACCEL_VISIBLE);
 
 	menu_item = gtk_menu_item_new_with_mnemonic ("_About");
 	gtk_widget_show (menu_item);
 	gtk_container_add (GTK_CONTAINER (sub_menu), menu_item);
 	g_signal_connect(menu_item, "activate", (GCallback) mplcfitx, NULL);
 	
-	menu_item = gtk_menu_item_new ();
+	menu_item = gtk_separator_menu_item_new();
 	gtk_widget_show (menu_item);
 	gtk_container_add (GTK_CONTAINER (sub_menu), menu_item);
-	gtk_widget_set_sensitive (menu_item, FALSE);
 
 	menu_item = gtk_menu_item_new_with_mnemonic ("_Visit terminatorX.org");
 	gtk_widget_show (menu_item);
@@ -1436,8 +1314,18 @@ void create_mastergui(int x, int y)
 	gtk_window_set_title(GTK_WINDOW(main_window), "terminatorX");
 
 	gtk_widget_realize(main_window);
+	
+	GtkWidget *posLabel=gtk_label_new("Pos:");
+	PangoRectangle ink_rect;
+	PangoRectangle logical_rect;
+	pango_layout_get_pixel_extents(gtk_label_get_layout(GTK_LABEL(posLabel)), &ink_rect, &logical_rect);
+	tX_debug("ink extent: x: %i, y: %i, width: %i, height %i ",  ink_rect.x, ink_rect.y, ink_rect.width, ink_rect.height);
+	tX_debug("logical extent: x: %i, y: %i, width: %i, height %i ",  logical_rect.x, logical_rect.y, logical_rect.width, logical_rect.height);
+	fontHeight = logical_rect.height - logical_rect.y;
 
-	wrapbox=gtk_vbox_new(FALSE, 5);
+	tx_icons_init(fontHeight);
+
+	wrapbox=gtk_box_new(GTK_ORIENTATION_VERTICAL, 5);
 	gtk_container_add(GTK_CONTAINER(main_window), wrapbox);
 	gtk_widget_show(wrapbox);
 
@@ -1445,8 +1333,10 @@ void create_mastergui(int x, int y)
 	gtk_box_pack_start(GTK_BOX(wrapbox), main_menubar, WID_FIX);
 	gtk_widget_show(main_menubar);
 
-	mother_of_all_boxen=gtk_vbox_new(FALSE, 5);
+	mother_of_all_boxen=gtk_box_new(GTK_ORIENTATION_VERTICAL, 5);
 	gtk_container_set_border_width(GTK_CONTAINER(mother_of_all_boxen), 5);
+	gtk_widget_set_hexpand(mother_of_all_boxen, TRUE);
+	gtk_widget_set_vexpand(mother_of_all_boxen, TRUE);
 	gtk_container_add(GTK_CONTAINER(wrapbox), mother_of_all_boxen);
 	gtk_widget_show(mother_of_all_boxen);	
 
@@ -1458,19 +1348,19 @@ void create_mastergui(int x, int y)
 	g_signal_connect(G_OBJECT(main_window), "key_press_event", G_CALLBACK(tx_mouse::key_press_wrap), &mouse);
 	g_signal_connect(G_OBJECT(main_window), "key_release_event", G_CALLBACK(tx_mouse::key_release_wrap), &mouse);
 	
-	main_vbox=gtk_hbox_new(FALSE, 5);
+	main_vbox=gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 5);
 	gtk_box_pack_start(GTK_BOX(mother_of_all_boxen), main_vbox, WID_DYN);
 	gtk_widget_show(main_vbox);
 	
-	left_hbox=gtk_vbox_new(FALSE, 5);
+	left_hbox=gtk_box_new(GTK_ORIENTATION_VERTICAL, 5);
 	gtk_box_pack_start(GTK_BOX(main_vbox), left_hbox, WID_DYN);
 	gtk_widget_show(left_hbox);
 	
-	control_box=gtk_hbox_new(FALSE, 5);
+	control_box=gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 5);
 	gtk_box_pack_start(GTK_BOX(left_hbox), control_box, WID_FIX);
 	gtk_widget_show(control_box);
 	
-	dummy=gtk_hseparator_new();
+	dummy=gtk_separator_new(GTK_ORIENTATION_HORIZONTAL);
 	gtk_box_pack_start(GTK_BOX(left_hbox), dummy, WID_FIX);
 	gtk_widget_show(dummy);
 
@@ -1493,7 +1383,7 @@ void create_mastergui(int x, int y)
 	gui_set_tooltip(grab_button, "Enter the mouse grab mode operation. Press <ESCAPE> to exit grab mode.");
 	gtk_widget_show(grab_button);
 
-	dummy=gtk_vseparator_new();
+	dummy=gtk_separator_new(GTK_ORIENTATION_VERTICAL);
 	gtk_box_pack_start(GTK_BOX(control_box), dummy, WID_FIX);
 	gtk_widget_show(dummy);
     
@@ -1522,9 +1412,8 @@ void create_mastergui(int x, int y)
 	gui_set_tooltip(dummy, "Enable recording of *events* into the sequencer. All touched controls will be recorded. Existing events for the song-time recording will be overwritten for touched controls.");
 	gtk_widget_show(dummy);
 
-	dummy=gtk_label_new("Pos:");
-	gtk_box_pack_start(GTK_BOX(control_box), dummy, WID_FIX);
-	gtk_widget_show(dummy);
+	gtk_box_pack_start(GTK_BOX(control_box), posLabel, WID_FIX);
+	gtk_widget_show(posLabel);
 	
 	dummy=gtk_entry_new();
 	gtk_entry_set_max_length(GTK_ENTRY(dummy), 12);
@@ -1535,13 +1424,14 @@ void create_mastergui(int x, int y)
 	gtk_entry_set_alignment(GTK_ENTRY(dummy), 0.5);
 #endif	
 	gtk_entry_set_width_chars(GTK_ENTRY(dummy), 9);
+	gtk_entry_set_max_width_chars(GTK_ENTRY(dummy), 9);
 	gtk_box_pack_start(GTK_BOX(control_box), dummy, WID_FIX);
 	gtk_widget_show(dummy);
 
 	dumadj=(GtkAdjustment*) gtk_adjustment_new(0, 0, 100, 0.1, 1, 1);
 	seq_adj=dumadj;
 	connect_adj(dumadj, sequencer_move, NULL);	
-	dummy=gtk_hscale_new(dumadj);
+	dummy=gtk_scale_new(GTK_ORIENTATION_HORIZONTAL, dumadj);
 	gtk_widget_set_size_request(dummy, 65, 20);
 	seq_slider=dummy;
 	g_signal_connect(G_OBJECT(seq_slider), "button-release-event", (GCallback) seq_slider_released, NULL);
@@ -1551,32 +1441,33 @@ void create_mastergui(int x, int y)
 	gtk_box_pack_start(GTK_BOX(control_box), dummy, WID_DYN);
 	gtk_widget_show(dummy);
 	
-	dummy=gtk_hbox_new(FALSE,2); //gtk_hpaned_new ();
+	dummy=gtk_box_new(GTK_ORIENTATION_HORIZONTAL,2); //gtk_hpaned_new ();
 	gtk_box_pack_start(GTK_BOX(left_hbox), dummy, WID_DYN);
 	gtk_widget_show(dummy);
 	
 	tt_parent=dummy;
 
-    panel_bar=gtk_hbox_new(TRUE,0);
+    panel_bar=gtk_box_new(GTK_ORIENTATION_HORIZONTAL,0);
+    gtk_box_set_homogeneous(GTK_BOX(panel_bar), TRUE);
 	gtk_box_pack_start(GTK_BOX(left_hbox), panel_bar, WID_FIX);
 
-	control_parent=gtk_hbox_new(FALSE,4);
+	control_parent=gtk_box_new(GTK_ORIENTATION_HORIZONTAL,4);
 	gtk_box_pack_start(GTK_BOX(tt_parent), control_parent, WID_FIX);
 	gtk_widget_show(control_parent);
 
-	dummy=gtk_vseparator_new();
+	dummy=gtk_separator_new(GTK_ORIENTATION_VERTICAL);
 	gtk_box_pack_start(GTK_BOX(tt_parent), dummy, WID_FIX);
 	gtk_widget_show(dummy);
 
-	audio_parent=gtk_vbox_new(FALSE,2);
+	audio_parent=gtk_box_new(GTK_ORIENTATION_VERTICAL,2);
 	gtk_box_pack_start(GTK_BOX(tt_parent), audio_parent, WID_DYN);
 	gtk_widget_show(audio_parent);
 	
-	dummy=gtk_vseparator_new();
+	dummy=gtk_separator_new(GTK_ORIENTATION_VERTICAL);
 	gtk_box_pack_start(GTK_BOX(main_vbox), dummy, WID_FIX);
 	gtk_widget_show(dummy);
 		
-	right_hbox=gtk_vbox_new(FALSE, 5);
+	right_hbox=gtk_box_new(GTK_ORIENTATION_VERTICAL, 5);
 	gtk_box_pack_start(GTK_BOX(main_vbox), right_hbox, WID_FIX);
 	gtk_widget_show(right_hbox);
 
@@ -1584,11 +1475,10 @@ void create_mastergui(int x, int y)
 	
 	dummy=gtk_label_new(NULL);
 	gtk_label_set_markup(GTK_LABEL(dummy),"<b>Master</b>");
-	gtk_misc_set_alignment(GTK_MISC(dummy), 0.5, 0.5);
 	gtk_box_pack_start(GTK_BOX(right_hbox), dummy, WID_FIX);
 	gtk_widget_show(dummy);	
 
-	dummy=gtk_hseparator_new();
+	dummy=gtk_separator_new(GTK_ORIENTATION_HORIZONTAL);
 	gtk_box_pack_start(GTK_BOX(right_hbox), dummy, WID_FIX);
 	gtk_widget_show(dummy);
 
@@ -1606,22 +1496,22 @@ void create_mastergui(int x, int y)
 	gtk_box_pack_start(GTK_BOX(right_hbox), pdial->get_widget(), WID_FIX);
 	gui_set_tooltip(pdial->get_entry(), "Use this dial to adjust the master pitch (affecting *all* turntables).");
 	
-	dummy=gtk_hseparator_new();
+	dummy=gtk_separator_new(GTK_ORIENTATION_HORIZONTAL);
 	gtk_box_pack_start(GTK_BOX(right_hbox), dummy, WID_FIX);
 	gtk_widget_show(dummy);
 	
 	/* Volume */
-	master_vol_box=gtk_hbox_new(FALSE, 5);
+	master_vol_box=gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 5);
 	gtk_box_pack_start(GTK_BOX(right_hbox), master_vol_box, WID_DYN);
-	gtk_widget_show(master_vol_box);	
+	gtk_widget_show(master_vol_box);
 	
 	dumadj=(GtkAdjustment*) gtk_adjustment_new(globals.volume, 0, 2, 0.01, 0.05, 0.000);
 	volume_adj=dumadj;
 
-	connect_adj(dumadj, master_volume_changed, NULL);	
-	dummy=gtk_vscale_new(dumadj);
+	connect_adj(dumadj, master_volume_changed, NULL);
+	dummy=gtk_scale_new(GTK_ORIENTATION_VERTICAL, dumadj);
 	gtk_range_set_inverted(GTK_RANGE(dummy), TRUE);
-	gtk_scale_set_draw_value(GTK_SCALE(dummy), False);
+	gtk_scale_set_draw_value(GTK_SCALE(dummy), FALSE);
 	g_signal_connect(G_OBJECT(dummy), "button_press_event", (GCallback) tX_seqpar::tX_seqpar_press, &sp_master_volume);	
 	
 	gtk_box_pack_end(GTK_BOX(master_vol_box), dummy, WID_FIX);
@@ -1633,27 +1523,26 @@ void create_mastergui(int x, int y)
 	gtk_widget_show(main_flash);
 
 	dummy=gtk_label_new("Volume");
-	gtk_misc_set_alignment(GTK_MISC(dummy), 0.5, 0.5);
 	gtk_box_pack_start(GTK_BOX(right_hbox), dummy, WID_FIX);
 	gtk_widget_show(dummy);
 
 	/* STATUS BOX */ 
-	dummy=gtk_hseparator_new();
+	dummy=gtk_separator_new(GTK_ORIENTATION_HORIZONTAL);
 	gtk_box_pack_start(GTK_BOX(right_hbox), dummy, WID_FIX);
 	gtk_widget_show(dummy);
 	
-	status_box=gtk_vbox_new(FALSE, 0);
+	status_box=gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
 	gtk_box_pack_start(GTK_BOX(right_hbox), status_box, WID_FIX);
 	gtk_widget_show(status_box);
 	
 	dummy=gtk_label_new("0");
 	used_mem=dummy;
-	gtk_misc_set_alignment(GTK_MISC(dummy), 1, 0.5);
+	gtk_widget_set_halign(dummy, GTK_ALIGN_END);
 	gtk_box_pack_end(GTK_BOX(status_box), dummy, WID_FIX);
 	gtk_widget_show(dummy);
 
 //	dummy=gtk_label_new("Mem/MB:");
-//	gtk_misc_set_alignment(GTK_MISC(dummy), 0, 0.5);
+//	gtk_widget_set_halign(dummy, GTK_ALIGN_START);
 //	gtk_box_pack_end(GTK_BOX(status_box), dummy, WID_FIX);
 //	gtk_widget_show(dummy);
 	
@@ -1661,24 +1550,24 @@ void create_mastergui(int x, int y)
 
 	dummy=gtk_label_new("1");
 	no_of_vtts=dummy;
-	gtk_misc_set_alignment(GTK_MISC(dummy), 1, 0.5);
+	gtk_widget_set_halign(dummy, GTK_ALIGN_END);
 	gtk_box_pack_end(GTK_BOX(status_box), dummy, WID_FIX);
 	gtk_widget_show(dummy);
 
 	dummy=gtk_label_new("Vtts:");
-	gtk_misc_set_alignment(GTK_MISC(dummy), 0, 0.5);
+	gtk_widget_set_halign(dummy, GTK_ALIGN_START);
 	gtk_box_pack_end(GTK_BOX(status_box), dummy, WID_FIX);
 	gtk_widget_show(dummy);*/
 
 	add_sep2();
 
-	dummy=gtk_label_new("v"VERSION);
-	gtk_misc_set_alignment(GTK_MISC(dummy), 1, 0.5);
+	dummy=gtk_label_new("v" VERSION);
+	gtk_widget_set_halign(dummy, GTK_ALIGN_END);
 	gtk_box_pack_end(GTK_BOX(status_box), dummy, WID_FIX);
 	gtk_widget_show(dummy);
 
 	/*dummy=gtk_label_new("Release:");
-	gtk_misc_set_alignment(GTK_MISC(dummy), 0, 0.5);
+	gtk_widget_set_halign(dummy, GTK_ALIGN_START);
 	gtk_box_pack_end(GTK_BOX(status_box), dummy, WID_FIX);
 	gtk_widget_show(dummy);*/
 	
@@ -1686,7 +1575,6 @@ void create_mastergui(int x, int y)
 
 	dummy=gtk_label_new(NULL);
 	gtk_label_set_markup(GTK_LABEL(dummy), "<b>Status</b>");
-	gtk_misc_set_alignment(GTK_MISC(dummy), 0.5, 0.5);
 	gtk_box_pack_end(GTK_BOX(status_box), dummy, WID_FIX);
 	gtk_widget_show(dummy);
 	
@@ -1715,9 +1603,10 @@ void tx_note(const char *message, bool isError, GtkWindow *window)
 {
 	if (!window) window=GTK_WINDOW(main_window);
 	
-	GtkWidget *dialog=gtk_message_dialog_new(window,
+	GtkWidget *dialog=gtk_message_dialog_new_with_markup(window,
 		GTK_DIALOG_DESTROY_WITH_PARENT,
-		isError ? GTK_MESSAGE_ERROR : GTK_MESSAGE_INFO, GTK_BUTTONS_CLOSE, "%s", message);
+		isError ? GTK_MESSAGE_ERROR : GTK_MESSAGE_INFO, GTK_BUTTONS_CLOSE, "%s", "");
+	gtk_message_dialog_set_markup(GTK_MESSAGE_DIALOG(dialog), message);
 	gtk_dialog_run(GTK_DIALOG(dialog));
 	gtk_widget_destroy(dialog);	
 }
@@ -1748,6 +1637,7 @@ void remove_from_panel_bar(GtkWidget *button)
 	if (buttons_on_panel_bar==0) gtk_widget_hide(panel_bar);
 }
 
+#ifdef USE_X11
 /* Fullscreen code... */
 #define _WIN_LAYER_TOP 		-1
 #define _WIN_LAYER_NORMAL	4
@@ -1796,18 +1686,22 @@ void fullscreen_setup() {
 		fullscreen_toggle(NULL, NULL);
 	}
 }
+#endif
 
 void display_mastergui()
 {
 	GtkWidget *top;
 	gtk_widget_realize(main_window);
 	tX_set_icon(main_window);
-	load_knob_pixs();
+	load_knob_pixs(fontHeight, gdk_window_get_scale_factor(gtk_widget_get_window(GTK_WIDGET(main_window))));
 	gtk_widget_show(main_window);
-	fullscreen_setup();	
 	top=gtk_widget_get_toplevel(main_window);
 	top_window=GDK_WINDOW(gtk_widget_get_window(top));
-	x_window=GDK_WINDOW_XWINDOW(gtk_widget_get_window(top));
+
+#ifdef USE_X11	
+	fullscreen_setup();	
+	x_window=gdk_x11_window_get_xid(gtk_widget_get_window(top));
+#endif
 }
 
 pid_t help_child=0;
@@ -1897,18 +1791,19 @@ tX_cursor::cursor_shape tX_cursor::current_shape=tX_cursor::DEFAULT_CURSOR;
 
 void tX_cursor::set_cursor(cursor_shape shape)
 {
+	GdkDisplay *display = gdk_window_get_display(gtk_widget_get_window(main_window));
 	switch (shape) {
 		case DEFAULT_CURSOR:
 			cursors[shape]=NULL;
 			break;
 		
 		case WAIT_CURSOR:
-			if (!cursors[shape]) cursors[shape]=gdk_cursor_new(GDK_WATCH);
+			if (!cursors[shape]) cursors[shape]=gdk_cursor_new_for_display(display, GDK_WATCH);
 			break;
 		
 		case WAIT_A_SECOND_CURSOR:
 			/* FIXME: What's that short-time wait cursor's id? */
-			if (!cursors[shape]) cursors[shape]=gdk_cursor_new(GDK_WATCH);
+			if (!cursors[shape]) cursors[shape]=gdk_cursor_new_for_display(display, GDK_WATCH);
 			break;
 		
 		default:
