@@ -1,6 +1,6 @@
 /*
     terminatorX - realtime audio scratching software
-    Copyright (C) 1999-2014  Alexander König
+    Copyright (C) 1999-2016  Alexander König
  
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -24,12 +24,12 @@
 #define _h_tx_mastergui 1
 
 #include <gtk/gtk.h>
-#include <X11/Xlib.h>
 
 #include "tX_seqpar.h"
+#include "tX_mouse.h"
 
 extern int audioon;
-extern Window x_window;
+extern tx_mouse mouse;
 extern GdkWindow* top_window;
 
 extern GtkWidget *main_window;
