@@ -1,6 +1,6 @@
 /*
     terminatorX - realtime audio scratching software
-    Copyright (C) 1999-2014  Alexander König
+    Copyright (C) 1999-2016  Alexander König
  
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -29,126 +29,94 @@
 
 #include <tX_types.h>
 #include <unistd.h>
-#include <X11/Xlib.h>
-#include <X11/extensions/XInput.h>
-#include <X11/keysym.h>
 #include <glib.h>
 #include <gdk/gdk.h>
 #include <gdk/gdkkeysyms.h>
 #include <gtk/gtk.h>
+#include <stdint.h>
 
-/* Use old gdk keys if the new ones are not yet defined */
+#define KEY_Alt_L 1
+#define KEY_Alt_R 2
+#define KEY_BackSpace 3
+#define KEY_Control_L 4
+#define KEY_Control_R 5
+#define KEY_Escape 6
+#define KEY_f 7
+#define KEY_F1 8
+#define KEY_F10 9
+#define KEY_F11 10
+#define KEY_F12 11
+#define KEY_F2 12
+#define KEY_F3 13
+#define KEY_F4 14
+#define KEY_F5 15
+#define KEY_F6 16
+#define KEY_F7 17
+#define KEY_F8 18
+#define KEY_F9 19
+#define KEY_m  20
+#define KEY_Return 21
+#define KEY_s 22
+#define KEY_space 23
+#define KEY_Tab 24
+#define KEY_w 25
+#define MAX_KEY 26
 
-#ifndef GDK_KEY_Alt_L
-#define GDK_KEY_Alt_L GDK_Alt_L
-#endif
-#ifndef GDK_KEY_Alt_R
-#define GDK_KEY_Alt_R GDK_Alt_R
-#endif
-#ifndef GDK_KEY_BackSpace
-#define GDK_KEY_BackSpace GDK_BackSpace
-#endif
-#ifndef GDK_KEY_Control_L
-#define GDK_KEY_Control_L GDK_Control_L
-#endif
-#ifndef GDK_KEY_Control_R
-#define GDK_KEY_Control_R GDK_Control_R
-#endif
-#ifndef GDK_KEY_Escape
-#define GDK_KEY_Escape GDK_Escape
-#endif
-#ifndef GDK_KEY_f
-#define GDK_KEY_f GDK_f
-#endif
-#ifndef GDK_KEY_F1
-#define GDK_KEY_F1 GDK_F1
-#endif
-#ifndef GDK_KEY_F10
-#define GDK_KEY_F10 GDK_F10
-#endif
-#ifndef GDK_KEY_F11
-#define GDK_KEY_F11 GDK_F11
-#endif
-#ifndef GDK_KEY_F12
-#define GDK_KEY_F12 GDK_F12
-#endif
-#ifndef GDK_KEY_F2
-#define GDK_KEY_F2 GDK_F2
-#endif
-#ifndef GDK_KEY_F3
-#define GDK_KEY_F3 GDK_F3
-#endif
-#ifndef GDK_KEY_F4
-#define GDK_KEY_F4 GDK_F4
-#endif
-#ifndef GDK_KEY_F5
-#define GDK_KEY_F5 GDK_F5
-#endif
-#ifndef GDK_KEY_F6
-#define GDK_KEY_F6 GDK_F6
-#endif
-#ifndef GDK_KEY_F7
-#define GDK_KEY_F7 GDK_F7
-#endif
-#ifndef GDK_KEY_F8
-#define GDK_KEY_F8 GDK_F8
-#endif
-#ifndef GDK_KEY_F9
-#define GDK_KEY_F9 GDK_F9
-#endif
-#ifndef GDK_KEY_m
-#define GDK_KEY_m GDK_m
-#endif
-#ifndef GDK_KEY_Return
-#define GDK_KEY_Return GDK_Return
-#endif
-#ifndef GDK_KEY_s
-#define GDK_KEY_s GDK_s
-#endif
-#ifndef GDK_KEY_space
-#define GDK_KEY_space GDK_space
-#endif
-#ifndef GDK_KEY_Tab
-#define GDK_KEY_Tab GDK_Tab
-#endif
-#ifndef GDK_KEY_w
-#define GDK_KEY_w GDK_w
-#endif
-#ifndef GDK_KEY_space
-#define GDK_KEY_space GDK_space
-#endif
+typedef struct __attribute__((__packed__)) {
+	uint8_t buttons;
+	int8_t x_motion;
+	int8_t y_motion;
+} tx_input_event;
 
 class tx_mouse
 {
-	XID OrgXPointer;
-	char OrgXPointerName[256];
-	XDevice *input_device;
-	XEvent xev;
-	long mask;
-	XMotionEvent *xmot;
-	XKeyEvent *xkey;
-	XButtonEvent *xbut;
 	bool warp_override;
 	GdkEventMask savedEventMask;
 
 	gboolean enable_auto_mnemonics;
+	gboolean enable_compression;
 	guint last_button_press;
 	guint last_button_release;
 
-#ifdef USE_DGA2	
-	XEvent xev_copy;
-	XDGAButtonEvent *xdgabut;
-	XDGAKeyEvent *xdgakey;
-	XDGAMotionEvent *xdgamot;
-#endif	
-	
-	Time otime, ntime;
-	f_prec dtime;
-	Display *dpy;
-	KeySym key;
+	GdkDevice* pointer;
+	GdkDevice* keyboard;
+	GdkScreen* screen;
+	GdkWindow* window;
+	GdkCursor* blankCursor;
+	GdkCursor* cursor;
+	gdouble x_abs;
+	gdouble y_abs;
+	gint x_restore;
+	gint y_restore;
+
 	float warp;
 	
 	int grabbed;
+	bool key_pressed[MAX_KEY];
+	
+	enum  {
+		FALLBACK,
+		LINUX_INPUT
+	} grab_mode;
+	
+	GIOChannel *linux_input_channel;
+	guint linux_input_watch;
+
+	bool press_key(int keycode) {
+		if (!key_pressed[keycode]) {
+			key_pressed[keycode] = true;
+			return true;
+		}
+		return false;
+	}
+
+	bool release_key(int keycode) {
+		if (key_pressed[keycode]) {
+			key_pressed[keycode] = false;
+			return true;
+		}
+		return false;
+	}
 
 	public:
 	int set_xinput();
@@ -156,24 +124,29 @@ class tx_mouse
 	bool is_grabbed() { return grabbed != 0; }
 		
 	int grab();
+	int grab_linux_input();
+		
 	int check_event();
 	void ungrab();
+	void ungrab_linux_input();
 	tx_mouse();
-	
+	GError *open_channel();
+	void close_channel();
+
 	void motion_notify(GtkWidget *widget, GdkEventMotion *eventMotion);
 	void button_press(GtkWidget *widget, GdkEventButton *eventButton);
 	void button_release(GtkWidget *widget, GdkEventButton *eventButton);
 	void key_press(GtkWidget *widget, GdkEventKey *eventKey);
 	void key_release(GtkWidget *widget, GdkEventKey *eventKey);
+	void linux_input(tx_input_event *event);
 
 	static gboolean motion_notify_wrap(GtkWidget *widget, GdkEventMotion *eventMotion, void *data);
 	static gboolean button_press_wrap(GtkWidget *widget, GdkEventButton *eventButton, void *data);
 	static gboolean button_release_wrap(GtkWidget *widget, GdkEventButton *eventButton, void *data);
 	static gboolean key_press_wrap(GtkWidget *widget, GdkEventKey *eventKey, void *data);
 	static gboolean key_release_wrap(GtkWidget *widget, GdkEventKey *eventKey, void *data);
+	static gboolean linux_input_wrap(GIOChannel *source, GIOCondition condition, gpointer data);
 
-	private:
-	void set_x_pointer(char*);
 };
 
 
