@@ -1,6 +1,6 @@
 /*
     terminatorX - realtime audio scratching software
-    Copyright (C) 1999-2014  Alexander König
+    Copyright (C) 1999-2016  Alexander König
  
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -68,10 +68,10 @@ tX_panel :: tX_panel (const char *name, GtkWidget *par)
 	pixmap_min=tx_pixmap_widget(MINIMIZE);
 	pixmap_max=tx_pixmap_widget(MAXIMIZE);
 	labelbutton=gtk_label_new(name);
-	gtk_misc_set_alignment(GTK_MISC(labelbutton), 0, 0.5);
+	gtk_widget_set_halign(labelbutton, GTK_ALIGN_START);
 	tX_panel_make_label_bold(labelbutton);
  
-	button_box=gtk_hbox_new(FALSE, 5);
+	button_box=gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 5);
 	       
 	gtk_box_pack_start(GTK_BOX(button_box), pixmap_min, WID_FIX);
 	gtk_box_pack_start(GTK_BOX(button_box), pixmap_max, WID_FIX);
@@ -80,10 +80,10 @@ tX_panel :: tX_panel (const char *name, GtkWidget *par)
 	gtk_container_set_border_width(GTK_CONTAINER(button_box), 2);
 	
 	gtk_container_add (GTK_CONTAINER (minbutton), button_box);
-	mainbox=gtk_vbox_new(FALSE, 0);
+	mainbox=gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
 	
-	topbox=gtk_hbox_new(FALSE, 0);
-	clientbox=gtk_vbox_new(FALSE, 0);
+	topbox=gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
+	clientbox=gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
 	clientframe=gtk_frame_new((char *) NULL);
 	gtk_container_set_border_width( GTK_CONTAINER(clientframe), 0);
 	gtk_container_add(GTK_CONTAINER(clientframe), clientbox);
