@@ -1,6 +1,6 @@
 /*
     terminatorX - realtime audio scratching software
-    Copyright (C) 1999-2014  Alexander König
+    Copyright (C) 1999-2016  Alexander König
  
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -43,7 +43,7 @@ typedef enum {
 } tX_icon;
 
 extern GtkWidget *tx_pixmap_widget(tX_icon id);
-extern void tx_icons_init();
+extern void tx_icons_init(int size);
 extern GtkWidget *tx_xpm_label_box(tX_icon id, const gchar *label_text, GtkWidget **labelwidget=(GtkWidget **) NULL);
 extern GtkWidget *tx_xpm_button_new(tX_icon id, const char *label, int toggle, GtkWidget **labelwidget=(GtkWidget **) NULL);
 #endif
