@@ -1,6 +1,6 @@
 /*
     terminatorX - realtime audio scratching software
-    Copyright (C) 1999-2014  Alexander König
+    Copyright (C) 1999-2016  Alexander König
  
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -63,7 +63,7 @@ class vtt_class
 	static int16_t *mix_out_buffer;
 	static f_prec mix_max_l;
 	static f_prec mix_max_r;
-	static int samples_in_mix_buffer;
+	static unsigned int samples_in_mix_buffer;
 	static pthread_mutex_t render_lock;
 	
 	static f_prec master_volume;
