@@ -1,6 +1,6 @@
 /*
     terminatorX - realtime audio scratching software
-    Copyright (C) 1999-2014  Alexander König
+    Copyright (C) 1999-2016  Alexander König
  
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -99,7 +99,6 @@ void pitch_changed(GtkWidget *wid, vtt_class *vtt)
 	vtt->sp_pitch.receive_gui_value(gtk_adjustment_get_value(GTK_ADJUSTMENT(wid)));
 }
 
-#ifdef USE_FILECHOOSER
 GCallback chooser_prelis(GtkWidget *w)
 {
 	GtkFileChooser *fc=GTK_FILE_CHOOSER(gtk_widget_get_toplevel(w));
@@ -113,30 +112,6 @@ GCallback chooser_prelis(GtkWidget *w)
 	}
 	return NULL;
 }
-#else
-GCallback trigger_prelis(GtkWidget *w)
-{
-	GtkFileSelection *fs;
-
-	fs=GTK_FILE_SELECTION(gtk_widget_get_toplevel(w));
-	
-	prelis_start((char *) gtk_file_selection_get_filename(GTK_FILE_SELECTION(fs)));
-	return NULL;
-}
-
-void cancel_load_file(GtkWidget *wid, vtt_class *vtt)
-{
-	prelis_stop();
-	
-	vtt->gui.file_dialog=NULL;
-	if (vtt->gui.fs) gtk_widget_destroy(GTK_WIDGET(vtt->gui.fs));
-}
-
-int quit_load_file(GtkWidget *wid, vtt_class *vtt)
-{
-	return 1;
-}
-#endif
 
 char global_filename_buffer[PATH_MAX];
 
@@ -215,24 +190,6 @@ void load_part(char *newfile, vtt_class *vtt)
 	}	
 }
 
-#ifndef USE_FILECHOOSER
-void do_load_file(GtkWidget *wid, vtt_class *vtt)
-{
-	char newfile[PATH_MAX];
-	
-	prelis_stop();
-
-	strcpy(newfile, gtk_file_selection_get_filename(GTK_FILE_SELECTION(vtt->gui.fs)));
-	gtk_widget_destroy(GTK_WIDGET(vtt->gui.fs));
-	vtt->gui.file_dialog=NULL;
-	
-	tX_cursor::set_cursor(tX_cursor::WAIT_CURSOR);
-	load_part(newfile, vtt);
-	strcpy(globals.current_path, newfile);
-	tX_cursor::reset_cursor();
-}
-#endif
-
 void drop_file(GtkWidget *widget, GdkDragContext *context,
 		gint x, gint y, GtkSelectionData *selection_data,
 		guint info, guint time, vtt_class *vtt)
@@ -265,16 +222,15 @@ void drop_file(GtkWidget *widget, GdkDragContext *context,
 }
 
 GCallback load_file(GtkWidget *wid, vtt_class *vtt)
-{	
-#ifdef USE_FILECHOOSER
+{
 	const char *extensions[]={ "mp3", "wav", "ogg", "flac", "iff", "aiff", "voc", "au", "spx", NULL };
 	char name_buf[512];
 	sprintf(name_buf, "Select Audio File for %s", vtt->name);
 	
 	GtkWidget * dialog = gtk_file_chooser_dialog_new (name_buf,
 		GTK_WINDOW(main_window), GTK_FILE_CHOOSER_ACTION_OPEN, 
-		GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL, 
-		GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT, NULL);
+		"_Cancel", GTK_RESPONSE_CANCEL, 
+		"_Open", GTK_RESPONSE_ACCEPT, NULL);
 
 		
 	GtkFileFilter *filter=gtk_file_filter_new();
@@ -315,31 +271,7 @@ GCallback load_file(GtkWidget *wid, vtt_class *vtt)
 	
 	prelis_stop();
 	gtk_widget_destroy(dialog);	
-#else
-	char buffer[512];
-	
-	if (vtt->gui.file_dialog) {
-		gdk_window_raise(vtt->gui.file_dialog);
-		return(0);
-	}
-	
-	sprintf(buffer, "Select Audio File for %s", vtt->name);
-	vtt->gui.fs=gtk_file_selection_new(buffer);
-	
-	if (vtt->audiofile) {
-		gtk_file_selection_set_filename(GTK_FILE_SELECTION(vtt->gui.fs), vtt->filename);	
-	} else if (strlen(globals.current_path)>0 ) {
-		gtk_file_selection_set_filename(GTK_FILE_SELECTION(vtt->gui.fs),globals.current_path);
-	}
-	
-	gtk_widget_show(GTK_WIDGET(vtt->gui.fs));	
-	vtt->gui.file_dialog=vtt->gui.fs->window;
-	
-	g_signal_connect (G_OBJECT(GTK_FILE_SELECTION(vtt->gui.fs)->ok_button), "clicked", G_CALLBACK(do_load_file), vtt);
-	g_signal_connect (G_OBJECT(GTK_FILE_SELECTION(vtt->gui.fs)->cancel_button), "clicked", G_CALLBACK (cancel_load_file), vtt);	
-	g_signal_connect (G_OBJECT(vtt->gui.fs), "delete-event", G_CALLBACK(quit_load_file), vtt);	
-	g_signal_connect (G_OBJECT(GTK_FILE_SELECTION(vtt->gui.fs)->file_list), "cursor_changed", G_CALLBACK(trigger_prelis), vtt->gui.fs);		
-#endif	
+
 	return NULL;
 }
 
@@ -697,7 +629,7 @@ static gint vg_file_button_pressed(GtkWidget *wid, GdkEventButton *event, vtt_cl
 
 void vg_adjust_zoom(GtkWidget *wid, vtt_class *vtt) {	
 	GtkAdjustment *adj=gtk_range_get_adjustment(GTK_RANGE(vtt->gui.zoom));
-	gtk_tx_set_zoom(GTK_TX(vtt->gui.display), gtk_adjustment_get_value(adj)/100.0);
+	gtk_tx_set_zoom(GTK_TX(vtt->gui.display), gtk_adjustment_get_value(adj)/100.0, vtt->is_playing);
 }
 
 static gint fx_button_pressed(GtkWidget *wid, GdkEventButton *event, vtt_class *vtt)
@@ -706,7 +638,7 @@ static gint fx_button_pressed(GtkWidget *wid, GdkEventButton *event, vtt_class *
 
 	LADSPA_Class::set_current_vtt(vtt);
 
-	if (g->ladspa_menu) gtk_object_destroy(GTK_OBJECT(g->ladspa_menu));
+	if (g->ladspa_menu) gtk_widget_destroy(GTK_WIDGET(g->ladspa_menu));
 	g->ladspa_menu=LADSPA_Class::get_ladspa_menu();
 	gtk_menu_popup (GTK_MENU(g->ladspa_menu), NULL, NULL, NULL, NULL, 0, 0);
 
@@ -722,7 +654,7 @@ static gint stereo_fx_button_pressed(GtkWidget *wid, GdkEventButton *event, vtt_
 
 	LADSPA_Class::set_current_vtt(vtt);
 
-	if (g->ladspa_menu) gtk_object_destroy(GTK_OBJECT(g->ladspa_menu));
+	if (g->ladspa_menu) gtk_widget_destroy(GTK_WIDGET(g->ladspa_menu));
 	g->ladspa_menu=LADSPA_Class::get_stereo_ladspa_menu();
 	gtk_menu_popup (GTK_MENU(g->ladspa_menu), NULL, NULL, NULL, NULL, 0, 0);
 
@@ -759,6 +691,35 @@ void gui_set_name(vtt_class *vtt, char *newname)
 	}
 }
 
+f_prec gui_get_audio_x_zoom(vtt_class *vtt) {
+	return gtk_tx_get_zoom(GTK_TX(vtt->gui.display));
+}
+
+int vttgui_zoom_depth=0;
+
+void gui_set_audio_x_zoom(vtt_class *vtt, f_prec value) {
+	if (vttgui_zoom_depth==0) {
+		vttgui_zoom_depth=1;
+		gtk_range_set_value(GTK_RANGE(vtt->gui.zoom), value*100.0);
+		vttgui_zoom_depth=0;
+	} else {
+		gtk_tx_set_zoom(GTK_TX(vtt->gui.display), value, vtt->is_playing);
+	}
+}
+
+void gui_scroll_callback(GtkWidget *tx, GdkEventScroll *eventScroll, gpointer userdata) {
+	vtt_class *vtt = (vtt_class *) userdata;
+	f_prec zoom = gui_get_audio_x_zoom(vtt);
+
+	if ((eventScroll->direction == GDK_SCROLL_UP) || (eventScroll->direction == GDK_SCROLL_RIGHT)) {
+		zoom += 0.1;
+	} else if ((eventScroll->direction == GDK_SCROLL_DOWN) || (eventScroll->direction == GDK_SCROLL_LEFT)) {
+		zoom -= 0.1;
+	}
+	gui_set_audio_x_zoom(vtt, zoom);
+}
+
+
 #define connect_entry(wid, func); g_signal_connect(G_OBJECT(g->wid), "activate", G_CALLBACK(func), (void *) vtt);
 #define connect_adj(wid, func); g_signal_connect(G_OBJECT(g->wid), "value_changed", G_CALLBACK(func), (void *) vtt);
 #define connect_button(wid, func); g_signal_connect(G_OBJECT(g->wid), "clicked", G_CALLBACK(func), (void *) vtt);
@@ -813,6 +774,9 @@ void gui_connect_signals(vtt_class *vtt)
 	connect_button(control_minimize, minimize_control_panel);
 	connect_button(audio_minimize, minimize_audio_panel);
 
+	gtk_widget_add_events(GTK_WIDGET(g->display), GDK_SCROLL_MASK);
+  g_signal_connect(G_OBJECT(g->display), "scroll-event", G_CALLBACK(gui_scroll_callback), vtt);
+
 	static GtkTargetEntry drop_types [] = {
 		{ dnd_uri, 0, 0}
 	};
@@ -850,14 +814,15 @@ void build_vtt_gui(vtt_class *vtt)
 	g->ladspa_menu=NULL;
 
 	/* Building Audio Box */
-	g->audio_box=gtk_vbox_new(FALSE,2);
+	g->audio_box=gtk_box_new(GTK_ORIENTATION_VERTICAL,2);
 	gtk_widget_show(g->audio_box);
 	
-	tempbox2=gtk_hbox_new(FALSE,2);
+	tempbox2=gtk_box_new(GTK_ORIENTATION_HORIZONTAL,2);
 	gtk_widget_show(tempbox2);
 	gtk_box_pack_start(GTK_BOX(g->audio_box), tempbox2, WID_FIX);
 	
-	tempbox=gtk_hbox_new(TRUE,2);
+	tempbox=gtk_box_new(GTK_ORIENTATION_HORIZONTAL,2);
+	gtk_box_set_homogeneous(GTK_BOX(tempbox), TRUE);
 	gtk_widget_show(tempbox);
 	gtk_box_pack_start(GTK_BOX(tempbox2), tempbox, WID_DYN);
 
@@ -871,7 +836,8 @@ void build_vtt_gui(vtt_class *vtt)
 
 
 	g->audio_label=gtk_label_new(vtt->name);
-	gtk_misc_set_alignment(GTK_MISC(g->audio_label), 0.025, 0.5);
+	gtk_widget_set_halign(g->audio_label, GTK_ALIGN_START);
+	gtk_widget_set_margin_start(g->audio_label, 10);
 	gtk_widget_show(g->audio_label);
 	gtk_box_pack_start(GTK_BOX(tempbox), g->audio_label, WID_DYN);
 
@@ -897,13 +863,13 @@ void build_vtt_gui(vtt_class *vtt)
 	}
 #endif
 
-	tempbox=gtk_hbox_new(FALSE, 2);
+	tempbox=gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 2);
 
 	g->display=gtk_tx_new(vtt->buffer, vtt->samples_in_buffer);
 	gtk_box_pack_start(GTK_BOX(tempbox), g->display, WID_DYN);
 	gtk_widget_show(g->display);	
 	
-	g->zoom=gtk_vscale_new_with_range(0,99.0,1.0);
+	g->zoom=gtk_scale_new_with_range(GTK_ORIENTATION_VERTICAL, 0,99.0,1.0);
 	gtk_range_set_inverted(GTK_RANGE(g->zoom), TRUE);
 	gtk_scale_set_draw_value(GTK_SCALE(g->zoom), TRUE);
 	gtk_scale_set_digits(GTK_SCALE(g->zoom), 0);
@@ -919,10 +885,10 @@ void build_vtt_gui(vtt_class *vtt)
 	
 	/* Building Control Box */
 	
-	g->control_box=gtk_vbox_new(FALSE,2);
+	g->control_box=gtk_box_new(GTK_ORIENTATION_VERTICAL,2);
 	gtk_widget_show(g->control_box);
 
-	tempbox2=gtk_hbox_new(FALSE, 2);
+	tempbox2=gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 2);
 	gtk_widget_show(tempbox2);
 	gtk_box_pack_start(GTK_BOX(g->control_box), tempbox2, WID_FIX);
 
@@ -944,9 +910,12 @@ void build_vtt_gui(vtt_class *vtt)
 	gtk_widget_show(g->scrolled_win);
 	gtk_box_pack_start(GTK_BOX(g->control_box), g->scrolled_win, WID_DYN);
 				    
-	g->control_subbox=gtk_vbox_new(FALSE,0);
-	gtk_scrolled_window_add_with_viewport (
-                   GTK_SCROLLED_WINDOW (g->scrolled_win), g->control_subbox);
+	g->control_subbox=gtk_box_new(GTK_ORIENTATION_VERTICAL,0);
+#if GTK_CHECK_VERSION(3,8,0)
+	gtk_container_add(GTK_CONTAINER(g->scrolled_win), g->control_subbox);
+#else
+	gtk_scrolled_window_add_with_viewport(GTK_SCROLLED_WINDOW(g->scrolled_win), g->control_subbox);
+#endif
 	gtk_widget_show(g->control_subbox);
 		   
 
@@ -958,9 +927,11 @@ void build_vtt_gui(vtt_class *vtt)
 	g->name = gtk_entry_new();
 	gtk_entry_set_max_length(GTK_ENTRY(g->name), 256);
 	gtk_entry_set_text(GTK_ENTRY(g->name), vtt->name);
+	gtk_entry_set_width_chars(GTK_ENTRY(g->name), 10);
+	gtk_entry_set_max_width_chars(GTK_ENTRY(g->name), 10);
 	p->add_client_widget(g->name);
 	gui_set_tooltip(g->name, "Enter the turntable's name here.");
-	gtk_widget_set_size_request(g->name, 40, -1);
+	//gtk_widget_set_size_request(g->name, 40, -1);
 
 	g->del=gtk_button_new_with_label("Delete");
 	gui_set_tooltip(g->del, "Click here to annihilate this turntable. All events recorded for this turntable will be erased, too.");
@@ -1015,7 +986,7 @@ void build_vtt_gui(vtt_class *vtt)
 
 	gtk_box_pack_start(GTK_BOX(g->control_subbox), p->get_widget(), WID_FIX);
 	
-	g->fx_box=gtk_vbox_new(FALSE,0);
+	g->fx_box=gtk_box_new(GTK_ORIENTATION_VERTICAL,0);
 	gtk_box_pack_start(GTK_BOX(g->control_subbox), g->fx_box, WID_FIX);
 	gtk_widget_show(g->fx_box);
 	
@@ -1095,7 +1066,7 @@ void build_vtt_gui(vtt_class *vtt)
 
 	gtk_box_pack_start(GTK_BOX(g->fx_box), p->get_widget(), WID_FIX);
 	
-	g->stereo_fx_box=gtk_vbox_new(FALSE, 0);
+	g->stereo_fx_box=gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
 	gtk_box_pack_start(GTK_BOX(g->control_subbox), g->stereo_fx_box, WID_FIX);
 	gtk_widget_show(g->stereo_fx_box);
 	
@@ -1108,11 +1079,11 @@ void build_vtt_gui(vtt_class *vtt)
 
 	/* Output */
 	
-	tempbox=gtk_hbox_new(FALSE,2);
+	tempbox=gtk_box_new(GTK_ORIENTATION_HORIZONTAL,2);
 	gtk_widget_show(tempbox);
 	gtk_box_pack_end(GTK_BOX(g->control_box), tempbox, WID_FIX);
 	
-	tempbox2=gtk_vbox_new(FALSE,0);
+	tempbox2=gtk_box_new(GTK_ORIENTATION_VERTICAL,0);
 	gtk_widget_show(tempbox2);
 	gtk_box_pack_start(GTK_BOX(tempbox), tempbox2, WID_FIX);
 	
@@ -1128,7 +1099,7 @@ void build_vtt_gui(vtt_class *vtt)
 	gtk_box_pack_start(GTK_BOX(tempbox2), g->pand->get_widget(), WID_FIX);
 	gui_set_tooltip(g->pand->get_entry(), "Specifies the position of this turntable within the stereo spectrum: -1 -> left, 0-> center, 1->right.");
 
-	tempbox3=gtk_hbox_new(FALSE,2);
+	tempbox3=gtk_box_new(GTK_ORIENTATION_HORIZONTAL,2);
 	gtk_widget_show(tempbox3);
 
 	g->mute=gtk_check_button_new_with_label("M");
@@ -1145,13 +1116,13 @@ void build_vtt_gui(vtt_class *vtt)
 
 	gtk_box_pack_start(GTK_BOX(tempbox2), tempbox3, WID_FIX);
 
-	tempbox2=gtk_hbox_new(FALSE,0);
+	tempbox2=gtk_box_new(GTK_ORIENTATION_HORIZONTAL,0);
 	gtk_widget_show(tempbox2);
 	gtk_box_pack_start(GTK_BOX(tempbox), tempbox2, WID_FIX);
 	
 	g->volume=GTK_ADJUSTMENT(gtk_adjustment_new(2.0-vtt->rel_volume, 0, 2, 0.01, 0.01, 0.01));
-	dummy=gtk_vscale_new(GTK_ADJUSTMENT(g->volume)); 
-	gtk_scale_set_draw_value(GTK_SCALE(dummy), False);
+	dummy=gtk_scale_new(GTK_ORIENTATION_VERTICAL, GTK_ADJUSTMENT(g->volume)); 
+	gtk_scale_set_draw_value(GTK_SCALE(dummy), FALSE);
 	gui_set_tooltip(dummy, "Adjust this turntable's volume.");
 	g_signal_connect(G_OBJECT(dummy), "button_press_event", (GCallback) tX_seqpar::tX_seqpar_press, &vtt->sp_volume);	
 
@@ -1160,11 +1131,8 @@ void build_vtt_gui(vtt_class *vtt)
 
 	g->flash=gtk_tx_flash_new();
 	gtk_box_pack_start(GTK_BOX(tempbox2), g->flash, WID_FIX);
-	gtk_widget_show(g->flash);		
+	gtk_widget_show(g->flash);
 
-#ifndef USE_FILECHOOSER
-	g->file_dialog=NULL;
-#endif
 	gui_connect_signals(vtt);
 	
 	g->audio_minimized_panel_bar_button=NULL;
@@ -1209,7 +1177,7 @@ GtkWidget *vg_create_fx_bar(vtt_class *vtt, vtt_fx *effect, int showdel)
 	GtkWidget *pixmap;
 	GtkWidget *button;
 	
-	box=gtk_hbox_new(FALSE,0);
+	box=gtk_box_new(GTK_ORIENTATION_HORIZONTAL,0);
 
 	if (showdel) {
 		button=gtk_button_new();
@@ -1505,9 +1473,9 @@ void gui_clear_master_button(vtt_class *vtt)
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(vtt->gui.sync_master), 0);
 }
 
-void gui_show_frame(vtt_class *vtt, int show)
+void gui_show_focus(vtt_class *vtt, int show)
 {
-	gtk_tx_show_frame(GTK_TX(vtt->gui.display), show);
+	gtk_tx_show_focus(GTK_TX(vtt->gui.display), show);
 }
 
 #define vgui (*vtt)->gui
@@ -1534,19 +1502,3 @@ void vg_init_all_non_seqpars()
 	}	
 }
 
-f_prec gui_get_audio_x_zoom(vtt_class *vtt) {
-	return gtk_tx_get_zoom(GTK_TX(vtt->gui.display));
-}
-
-/* Yes, this is yet another evil hack. Fix it :) */
-int vttgui_zoom_depth=0;
-
-extern void gui_set_audio_x_zoom(vtt_class *vtt, f_prec value) {
-	if (vttgui_zoom_depth==0) {
-		vttgui_zoom_depth=1;
-		gtk_range_set_value(GTK_RANGE(vtt->gui.zoom), value*100.0);
-		vttgui_zoom_depth=0;
-	} else {
-		gtk_tx_set_zoom(GTK_TX(vtt->gui.display), value);
-	}
-}
