@@ -1,6 +1,6 @@
 /*
     terminatorX - realtime audio scratching software
-    Copyright (C) 1999-2014  Alexander König
+    Copyright (C) 1999-2016  Alexander König
  
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -98,11 +98,6 @@ struct vtt_gui
 	GtkAdjustment *ec_pan;
 	GtkAdjustment *ec_volume;
 
-#ifndef USE_FILECHOOSER	
-	GdkWindow *file_dialog;
-	GtkWidget *fs;
-#endif	
-	
 	int32_t current_gui;
 
 	/* Audio Box Widgets */
@@ -134,5 +129,6 @@ extern void update_all_vtts();
 extern void vg_enable_critical_buttons(int enable);
 extern void vg_init_all_non_seqpars();
 extern void vg_adjust_zoom(GtkWidget *wid, vtt_class *vtt);
+extern void gui_scroll_callback(GtkWidget *tx, GdkEventScroll *eventScroll, gpointer userdata);
 extern GCallback load_file(GtkWidget *wid, vtt_class *vtt);
 #endif
