@@ -1,6 +1,6 @@
 /*
     terminatorX - realtime audio scratching software
-    Copyright (C) 1999-2014  Alexander König
+    Copyright (C) 1999-2016  Alexander König
  
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -24,7 +24,7 @@
 #ifndef __GTK_TX_H__
 #define __GTK_TX_H__
 #include <gdk/gdk.h>
-#include <gtk/gtkwidget.h>
+#include <gtk/gtk.h>
 
 #include "tX_types.h"
 
@@ -32,7 +32,6 @@
 extern "C" {
 #endif /* __cplusplus */
 
-
 #define GTK_TX(obj)          G_TYPE_CHECK_INSTANCE_CAST (obj, gtk_tx_get_type (), GtkTx)
 #define GTK_TX_CLASS(klass)  GTK_CHECK_CLASS_CAST (klass, gtk_tx_get_type (), GtkTxClass)
 #define GTK_IS_TX(obj)       G_TYPE_CHECK_INSTANCE_TYPE (obj, gtk_tx_get_type ())
@@ -46,6 +45,8 @@ typedef enum tx_widget_motion {
 	MOTION_RIGHT
 } tx_widget_motion;
 
+#define GTK_TX_HISTORY_LENGTH 4 
+
 struct _GtkTx {
 	GtkWidget widget;
 
@@ -53,37 +54,45 @@ struct _GtkTx {
 	int16_t *data;
 	int samples;
 	
-	GdkColor colors[6];
+	GdkRGBA colors[6];
+	GdkRGBA history_colors[GTK_TX_HISTORY_LENGTH];
 	
-	GdkColor *current_fg;
-	GdkColor *current_bg;
+	GdkRGBA *current_fg;
+	GdkRGBA *current_bg;
 	
-	GdkColor *audio_colors_focus;
-	GdkColor *audio_colors_nofocus;
+	GdkRGBA *audio_colors_focus;
+	GdkRGBA *audio_colors_nofocus;
 	
 	int spp;
+	int xc;
+	int xmax;
 	int yc;
-	
-	int lastmute;
-	int do_showframe;
-	
-	GtkWidget *peer_scale;
+	int ymax;
 	
 	f_prec zoom;
 		
 	int cursor_pos;
 	int cursor_x_pos;
+	int mute;
+	int cursor_history[GTK_TX_HISTORY_LENGTH];
+	int cursor_history_offset;
 
 	int display_width;
 	int display_x_offset;
-	
-	int colors_allocated;
 
 #ifdef USE_DISPLAY_NORMALIZE
 	f_prec max_value;
 #endif	
 
-	cairo_surface_t* surface;
+	cairo_surface_t* render_buffer_surface_a;
+	cairo_surface_t* render_buffer_surface_b;
+
+	cairo_surface_t* current_render_buffer_surface;
+	cairo_surface_t* previous_render_buffer_surface;
+
+	int render_buffer_x_offset;
+	int render_buffer_display_width;
+	GdkRGBA *render_buffer_fg;
 };
 
 struct _GtkTxClass {
@@ -94,9 +103,9 @@ GtkWidget* gtk_tx_new	(int16_t *wavdata, int wavsamples);
 GType gtk_tx_get_type	(void);
 void gtk_tx_set_data  (GtkTx *tx, int16_t *wavdata, int wavsamples);
 void gtk_tx_cleanup_pos_display (GtkTx *tx);
-void	gtk_tx_update_pos_display  (GtkTx *tx, int sample, int mute);
-void gtk_tx_show_frame(GtkTx *tx, int show);
-void gtk_tx_set_zoom(GtkTx *tx, f_prec zoom);
+void gtk_tx_update_pos_display (GtkTx *tx, int sample, int mute);
+void gtk_tx_show_focus(GtkTx *tx, int show);
+void gtk_tx_set_zoom(GtkTx *tx, f_prec zoom, int is_playing);
 void gtk_tx_update_colors(GtkTx *tx);
 f_prec gtk_tx_get_zoom(GtkTx *tx);
 
